@@ -14,6 +14,8 @@
 
 #include "optable.h"
 #include "crosstab.h"
+#include "dstring.h"
+#include "pbook.h"
 
 uint
 endgameTheme (matSigT msig)
@@ -60,7 +62,7 @@ inline bool posHasAdvancedPawn (Position * pos, colorT c)
 
 inline bool posHasKPawnStorm (Position * pos, colorT c)
 {
-    pieceT * bd = pos->GetBoard();
+    const pieceT* bd = pos->GetBoard();
     // A kingside pawn storm by White is defined to be a situation
     // where there is no longer any white pawn on h2, g2, h3 or g3,
     // but there is a white pawn on the g or h file.
@@ -124,7 +126,7 @@ OpLine::Init (Game * g, const IndexEntry * ie, gamenumT gameNum,
     AvgElo = g->GetAverageElo();
     Length = 0;
     StartPly = g->GetCurrentPly();
-    g->SaveState();
+    auto location = g->currentLocation();
     if (g->GetCurrentPos()->GetToMove() == BLACK) {
         g->MoveBackup();
     }
@@ -178,7 +180,7 @@ OpLine::Init (Game * g, const IndexEntry * ie, gamenumT gameNum,
         SetPositionalThemes (g->GetCurrentPos());
     }
 
-    g->RestoreState();
+    g->restoreLocation(location);
 }
 
 
@@ -476,7 +478,6 @@ OpTable::Init (const char * type, Game * g, PBook * ebook)
     Results[RESULT_Draw] = Results[RESULT_None] = 0;
     TheoryResults[RESULT_White] = TheoryResults[RESULT_Black] = 0;
     TheoryResults[RESULT_Draw] = TheoryResults[RESULT_None] = 0;
-    EcoStr = NULL;
     ExcludeMove[0] = 0;
 
     uint i;
@@ -487,17 +488,16 @@ OpTable::Init (const char * type, Game * g, PBook * ebook)
     }
 
     // Generate the text for each move up to the current position:
-    g->SaveState();
+    auto location = g->currentLocation();
     while (! g->AtStart()) {
         if (g->AtVarStart()) {
             g->MoveExitVariation();
             continue;
         }
-        if (ebook != NULL  &&  EcoStr == NULL) {
-            DString dstr;
-            if (ebook->FindOpcode (g->GetCurrentPos(), "eco", &dstr) == OK) {
-                EcoStr = strDuplicate (dstr.Data());
-            }
+        if (ebook != NULL && ECOstr_.empty()) {
+            auto eco = ebook->findECOstr(g->GetCurrentPos());
+            if (eco.first)
+                ECOstr_.append(eco.first, eco.second);
         }
         g->MoveBackup();
         simpleMoveT * sm = g->GetCurrentMove();
@@ -507,7 +507,7 @@ OpTable::Init (const char * type, Game * g, PBook * ebook)
         StartLength++;
         if (StartLength >= OPTABLE_MAX_STARTLINE) { break; }
     }
-    g->RestoreState();
+    g->restoreLocation(location);
     // Now the moves are in the StartLine[] array, in reverse order.
 }
 
@@ -533,14 +533,6 @@ OpTable::Clear (void)
     Results[RESULT_Draw] = Results[RESULT_None] = 0;
     TheoryResults[RESULT_White] = TheoryResults[RESULT_Black] = 0;
     TheoryResults[RESULT_Draw] = TheoryResults[RESULT_None] = 0;
-    if (EcoStr != NULL) {
-#ifdef WINCE
-        my_Tcl_Free((char*) EcoStr);
-#else
-        delete[] EcoStr;
-#endif
-        EcoStr =  NULL;
-    }
     ExcludeMove[0] = 0;
 }
 
@@ -1080,7 +1072,6 @@ OpTable::PrintLaTeX (DString * dstr, const char * title, const char * comment)
 
     // Print each row:
     for (uint row=0; row < NumRows; row++) {
-        uint lastNote = 0;
         dstr->Append ("\\textbf{", row+1, "}");
         uint nSameMoves = 0;
         if (row > 0) { nSameMoves = Row[row]->CommonLength(Row[row-1]); }
@@ -1118,9 +1109,6 @@ OpTable::PrintLaTeX (DString * dstr, const char * title, const char * comment)
                 dstr->Append ("}}");
 #endif
                 dstr->Append ("$");
-                lastNote = NumNotes;
-            } else {
-                lastNote = 0;
             }
         }
 
@@ -1209,9 +1197,8 @@ OpTable::PrintText (DString * dstr, const char * title, const char * comment,
     MakeRows();
     NumNotes = 0;
     const uint cellBytes = 9;
-    char cell [16];
+    char cell [18];
     const char * hrule = "-------------------------------------------------------------------------------\n";
-    DString * dtemp = new DString;
 
     dstr->Append (title, "\n");
     if (ctext) { dstr->Append ("<tt>"); }
@@ -1241,8 +1228,10 @@ OpTable::PrintText (DString * dstr, const char * title, const char * comment,
     }
     dstr->Append ("\n", hrule);
 
-    DString * wstr = new DString;
-    DString * bstr = new DString;
+    DString wStr, bStr, dTemp;
+    DString* wstr = &wStr;
+    DString* bstr = &bStr;
+    DString* dtemp = &dTemp;
 
     // Print each row:
     for (uint row=0; row < NumRows; row++) {
@@ -1256,7 +1245,7 @@ OpTable::PrintText (DString * dstr, const char * title, const char * comment,
         uint nSameMoves = 0;
         if (row > 0) { nSameMoves = Row[row]->CommonLength(Row[row-1]); }
         for (uint j=0; j < 2*OPTABLE_COLUMNS; j++) {
-            uint width = 0;
+            size_t width = 0;
             dtemp->Clear();
             if (j < nSameMoves) {
                 dtemp->Append ("...");
@@ -1274,7 +1263,7 @@ OpTable::PrintText (DString * dstr, const char * title, const char * comment,
                     }
                     dtemp->Append ("}>");
                 }
-                uint oldwidth = dtemp->Length();
+                size_t oldwidth = dtemp->Length();
                 OpLine::PrintMove (dtemp, Row[row]->Move[j], OPTABLE_Compact);
                 width += dtemp->Length() - oldwidth;
                 if (ctext  &&  j >= nSameMoves) {
@@ -1288,7 +1277,7 @@ OpTable::PrintText (DString * dstr, const char * title, const char * comment,
                     dtemp->Append ("<red><go n", NumNotes, ">");
                     dtemp->Append ("<N", NumNotes, ">");
                 }
-                uint oldwidth = dtemp->Length();
+                size_t oldwidth = dtemp->Length();
                 dtemp->Append ("[", NumNotes, "]");
                 width += dtemp->Length() - oldwidth;
                 if (ctext) { dtemp->Append ("</N", NumNotes, "></go></red>"); }
@@ -1322,7 +1311,6 @@ OpTable::PrintText (DString * dstr, const char * title, const char * comment,
     dstr->Append (hrule);
     if (! strEqual (comment, "")) { dstr->Append (comment, "\n"); }
     dstr->Append ("\n");
-    delete dtemp;
     if (ctext) { dstr->Append ("</tt>"); }
     PrintNotes (dstr, ctext ? OPTABLE_CText : OPTABLE_Text);
 }
@@ -2115,17 +2103,17 @@ OpTable::ThemeReport (DString * dstr, uint argc, const char ** argv)
         nextCell = " & ";  nextCellRight = nextCell;
     }
 
-    const char * themeName [NUM_POSTHEMES] = {NULL};
-    themeName [POSTHEME_CastSame]  = "Same-side castling:         ";
-    themeName [POSTHEME_CastOpp]   = "Opposite castling:          ";
-    themeName [POSTHEME_QueenSwap] = "Queens exchanged:           ";
-    themeName [POSTHEME_OneBPair]  = "Only 1 side has Bishop pair:";
-    themeName [POSTHEME_Kstorm]    = "Kingside pawn storm:        ";
-    themeName [POSTHEME_WIQP]      = "White Isolated Queen Pawn:  ";
-    themeName [POSTHEME_BIQP]      = "Black Isolated Queen Pawn:  ";
-    themeName [POSTHEME_WAdvPawn]  = "White Pawn on 5/6/7th rank: ";
-    themeName [POSTHEME_BAdvPawn]  = "Black Pawn on 2/3/4th rank: ";
-    themeName [POSTHEME_OpenFyle]  = "Open c/d/e file:            ";
+    // const char * themeName [NUM_POSTHEMES] = {NULL};
+    // themeName [POSTHEME_CastSame]  = "Same-side castling:         ";
+    // themeName [POSTHEME_CastOpp]   = "Opposite castling:          ";
+    // themeName [POSTHEME_QueenSwap] = "Queens exchanged:           ";
+    // themeName [POSTHEME_OneBPair]  = "Only 1 side has Bishop pair:";
+    // themeName [POSTHEME_Kstorm]    = "Kingside pawn storm:        ";
+    // themeName [POSTHEME_WIQP]      = "White Isolated Queen Pawn:  ";
+    // themeName [POSTHEME_BIQP]      = "Black Isolated Queen Pawn:  ";
+    // themeName [POSTHEME_WAdvPawn]  = "White Pawn on 5/6/7th rank: ";
+    // themeName [POSTHEME_BAdvPawn]  = "Black Pawn on 2/3/4th rank: ";
+    // themeName [POSTHEME_OpenFyle]  = "Open c/d/e file:            ";
 
     char tempStr [250];
     //sprintf (tempStr, argv[0], (StartLength + (OPTABLE_COLUMNS * 2)) / 2);
