@@ -19,9 +19,9 @@
 #include "common.h"
 #include "misc.h"
 #include "scidbase.h"
+#include <algorithm>
 #include <string>
 #include <vector>
-#include <algorithm>
 
 namespace {
 
@@ -196,7 +196,7 @@ public:
 		if (min_ > max_) std::swap(min_, max_);
 		// Set eco maximum to be the largest subcode, for example,
 		// "B07" -> "B07z4" to make sure subcodes are included in the range:
-		max_ = eco_LastSubCode(max_);
+		max_ = eco_LastSubCode(static_cast<ecoT>(max_));
 	}
 };
 
@@ -210,7 +210,7 @@ public:
 		// so -1 = last game, -2 = second to last, etc.
 		if (min_ < 0) min_ += base->numGames();
 		else min_ -=1;
-		if (max_ < 0) min_ += base->numGames();
+		if (max_ < 0) max_ += base->numGames();
 		else max_ -=1;
 		if (min_ > max_) std::swap(min_, max_);
 	}
@@ -353,28 +353,25 @@ std::vector<SearchParam> parseParams(int argc, const char ** argv, filterOpT& fi
  *         @filter is reset to include all games
  *         @filterOp is changed to FILTEROP_AND
  */
-std::vector<gamenumT> gamesToSearch(const scidBaseT* base, HFilter& filter, filterOpT& filterOp) {
+std::vector<gamenumT> collectGames(HFilter& filter, filterOpT& filterOp) {
+	ASSERT(filter != 0);
+
 	std::vector<gamenumT> res;
-	res.reserve(base->numGames());
-
-	if (filterOp == FILTEROP_RESET) {
-		for (gamenumT i = 0, n=base->numGames(); i < n; i++) {
-			res.push_back(i);
-		}
-		filter.fill(1);
+	switch (filterOp) {
+	case FILTEROP_RESET:
+		filter->includeAll();
 		filterOp = FILTEROP_AND;
-	} else {
-		for (gamenumT i = 0, n=base->numGames(); i < n; i++) {
-			byte v = filter.get(i);
-			if (filterOp == FILTEROP_AND) {
-				if (v != 0) res.push_back(i);
-			} else {
-				//filterOp == FILTEROP_OR
-				if (v == 0) res.push_back(i);
-			}
-		}
+		/* FALLTHRU */
+	case FILTEROP_AND:
+		res.resize(filter->size());
+		std::copy(filter->begin(), filter->end(), res.begin());
+		break;
+	case FILTEROP_OR:
+		HFilterInverted excluded(filter);
+		res.resize(excluded.size());
+		std::copy(excluded.begin(), excluded.end(), res.begin());
+		break;
 	}
-
 	return res;
 }
 
@@ -391,64 +388,67 @@ std::vector<gamenumT> gamesToSearch(const scidBaseT* base, HFilter& filter, filt
  */
 template<typename I>
 I doSearch(I itB, I itR, I itE, const scidBaseT* base, SearchParam& param) {
-	if (param == "player") return std::partition(itB, itE,
+	if (param == "player") return std::stable_partition(itB, itE,
 		SearchName(base, param.getValue(), NAME_PLAYER, &IndexEntry::GetWhite, &IndexEntry::GetBlack)
 	);
-	if (param == "white") return std::partition(itB, itE,
+	if (param == "white") return std::stable_partition(itB, itE,
 		SearchName(base, param.getValue(), NAME_PLAYER, &IndexEntry::GetWhite)
 	);
-	if (param == "black") return std::partition(itB, itE,
+	if (param == "black") return std::stable_partition(itB, itE,
 		SearchName(base, param.getValue(), NAME_PLAYER, &IndexEntry::GetBlack)
 	);
-	if (param == "event") return std::partition(itB, itE,
+	if (param == "event") return std::stable_partition(itB, itE,
 		SearchName(base, param.getValue(), NAME_EVENT, &IndexEntry::GetEvent)
 	);
-	if (param == "site") return std::partition(itB, itE,
+	if (param == "site") return std::stable_partition(itB, itE,
 		SearchName(base, param.getValue(), NAME_SITE, &IndexEntry::GetSite)
 	);
-	if (param == "sitecountry") return std::partition(itB, itE,
+	if (param == "sitecountry") return std::stable_partition(itB, itE,
 		SearchSiteCountry(base, param.getValue())
 	);
-	if (param == "round") return std::partition(itB, itE,
+	if (param == "round") return std::stable_partition(itB, itE,
 		SearchName(base, param.getValue(), NAME_ROUND, &IndexEntry::GetRound)
 	);
-	if (param == "date") return std::partition(itB, itE,
+	if (param == "date") return std::stable_partition(itB, itE,
 		SearchRangeDate(base, param.getValue(), &IndexEntry::GetDate)
 	);
-	if (param == "elo") return std::partition(itB, itE,
+	if (param == "eventdate") return std::stable_partition(itB, itE,
+		SearchRangeDate(base, param.getValue(), &IndexEntry::GetEventDate)
+	);
+	if (param == "elo") return std::stable_partition(itB, itE,
 		SearchRangeElo(base, param.getValue(), &IndexEntry::GetWhiteElo, &IndexEntry::GetBlackElo)
 	);
-	if (param == "welo") return std::partition(itB, itE,
+	if (param == "welo") return std::stable_partition(itB, itE,
 		SearchRangeElo(base, param.getValue(), &IndexEntry::GetWhiteElo)
 	);
-	if (param == "belo") return std::partition(itB, itE,
+	if (param == "belo") return std::stable_partition(itB, itE,
 		SearchRangeElo(base, param.getValue(), &IndexEntry::GetBlackElo)
 	);
-	if (param == "delo") return std::partition(itB, itE,
+	if (param == "delo") return std::stable_partition(itB, itE,
 		SearchRangeEloDiff(base, param.getValue(), &IndexEntry::GetWhiteElo, &IndexEntry::GetBlackElo)
 	);
-	if (param == "eco") return std::partition(itB, itE,
+	if (param == "eco") return std::stable_partition(itB, itE,
 		SearchRangeEco(base, param.getValue(), &IndexEntry::GetEcoCode)
 	);
-	if (param == "gnum") return std::partition(itB, itE,
+	if (param == "gnum") return std::stable_partition(itB, itE,
 		SearchRangeGamenum(base, param.getValue())
 	);
-	if (param == "length") return std::partition(itB, itE,
+	if (param == "length") return std::stable_partition(itB, itE,
 		SearchRange<ushort>(base, param.getValue(), &IndexEntry::GetNumHalfMoves)
 	);
-	if (param == "n_variations") return std::partition(itB, itE,
+	if (param == "n_variations") return std::stable_partition(itB, itE,
 		SearchRange<uint>(base, param.getValue(), &IndexEntry::GetVariationCount)
 	);
-	if (param == "n_comments") return std::partition(itB, itE,
+	if (param == "n_comments") return std::stable_partition(itB, itE,
 		SearchRange<uint>(base, param.getValue(), &IndexEntry::GetCommentCount)
 	);
-	if (param == "n_nags") return std::partition(itB, itE,
+	if (param == "n_nags") return std::stable_partition(itB, itE,
 		SearchRange<uint>(base, param.getValue(), &IndexEntry::GetNagCount)
 	);
-	if (param == "flag") return std::partition(itB, itE,
+	if (param == "flag") return std::stable_partition(itB, itE,
 		SearchFlag(base, param.getValue())
 	);
-	if (param == "result") return std::partition(itB, itE,
+	if (param == "result") return std::stable_partition(itB, itE,
 		SearchResult(base, param.getValue())
 	);
 
@@ -461,12 +461,12 @@ I doSearch(I itB, I itR, I itE, const scidBaseT* base, SearchParam& param) {
 
 /**
  * search_index() - search for games using game's IndexEntry info
- * @base:     the scidBaseT to search
- * @filter:   the filter to be modified with the result of the search
- *            (RESET, AND, OR operations can be applied to the filter)
- * @argc:     number of argv elements
- * @argv:     an array of string pairs <criteria,value>
- * @progress: report search progress to UI
+ * @param base:     the scidBaseT to search
+ * @param filter:   the filter to be modified with the result of the search
+ *                  (RESET, AND, OR operations can be applied to the filter)
+ * @param argc:     number of argv elements
+ * @param argv:     an array of string pairs <criteria,value>
+ * @param progress: report search progress to UI
  *
  * This function perform a fast games search using the IndexEntry info.
  * Criteria should start with the char '-' and can include the optional trailing chars
@@ -498,13 +498,14 @@ I doSearch(I itB, I itR, I itE, const scidBaseT* base, SearchParam& param) {
  * -welo "2700 4000" -belo|! "0 2700" -delo "-200 200"
  * means (white elo > 2700 && white elo < 4000) || (belo is not in the range 0-2700) && ((welo - belo) > -200 && (welo - belo) < 200)
  */
-errorT search_index(const scidBaseT* base, HFilter& filter, int argc, const char ** argv, const Progress& progress)
-{
-	ASSERT(*filter);
+errorT search_index(const scidBaseT* base, HFilter& filter, int argc,
+                    const char** argv, const Progress& progress) {
+	ASSERT(base != 0);
+	ASSERT(filter != 0);
 
 	filterOpT filterOp = FILTEROP_RESET;
 	std::vector<SearchParam> params = parseParams(argc, argv, filterOp);
-	std::vector<gamenumT> glist = gamesToSearch(base, filter, filterOp);
+	std::vector<gamenumT> glist = collectGames(filter, filterOp);
 
 	// Partition glist so that the range [glist.begin(), it_res)
 	// contains the matching games
@@ -541,11 +542,13 @@ errorT search_index(const scidBaseT* base, HFilter& filter, int argc, const char
 
 	if (filterOp == FILTEROP_AND) {
 		// Remove nonmatching games from @filter
-		for (iter it = it_res; it != glist.end(); it++) filter.set(*it, 0);
+		for (iter it = it_res; it != glist.end(); ++it)
+			filter->erase(*it);
 	} else {
 		// filterOp == FILTEROP_OR
 		// Add matching games to @filter
-		for (iter it = glist.begin(); it != it_res; it++) filter.set(*it, 1);
+		for (iter it = glist.begin(); it != it_res; ++it)
+			filter->set(*it, 1);
 	}
 	progress.report(1,1);
 
