@@ -20,39 +20,26 @@ proc findNovelty {} {
     updateNoveltyWin
     return
   }
-  toplevel $w
+  win::createDialog $w
   wm title $w "Scid: $::tr(FindNovelty)"
   
-  pack [frame $w.help] -side top -fill x
-  text $w.help.text -width 1 -height 5 -wrap word \
-      -relief ridge -cursor top_left_arrow -yscrollcommand "$w.help.ybar set"
-  scrollbar $w.help.ybar -orient vertical -command "$w.help.text yview" \
-      -takefocus 0 -width 10
-  pack $w.help.ybar -side right -fill y
+  pack [ttk::frame $w.help] -side top -fill x
+  ttk::label $w.help.text -wraplength 3i -justify left -text $::tr(NoveltyHelp)
   pack $w.help.text -side left -fill x -expand yes
-  $w.help.text insert end [string trim $::tr(NoveltyHelp)]
-  $w.help.text configure -state disabled
-  
-  label $w.title -text $::tr(Database:) -font font_Bold
-  pack $w.title -side top
+  ttk::labelframe $w.bases -text $::tr(Database)
+  pack $w.bases -side top -fill x -pady 5
 
-  pack [frame $w.bases] -side top -fill x
-  pack [frame $w.bases.del]
-  addHorizontalRule $w
+  pack [ttk::frame $w.bases.del]
   
-  label $w.which -text $::tr(TwinsWhich:) -font font_Bold
-  pack $w.which -side top
-  radiobutton $w.all -text $::tr(SelectAllGames) \
+  ttk::labelframe $w.which -text $::tr(TwinsWhich)
+  pack $w.which -side top -fill x -pady 5
+  ttk::radiobutton $w.which.all -text $::tr(SelectAllGames) \
       -variable noveltyOlder -value 0
-  radiobutton $w.older -text $::tr(SelectOlderGames) \
+  ttk::radiobutton $w.which.older -text $::tr(SelectOlderGames) \
       -variable noveltyOlder -value 1
-  pack $w.all $w.older -side top -anchor w -padx 10
+  pack $w.which.all $w.which.older -side top -anchor w -fill x
   
-  addHorizontalRule $w
-  
-  label $w.status -text "" -width 1 -font font_Small -relief sunken -anchor w
-  pack $w.status -side bottom -fill x
-  pack [frame $w.b] -side top -fill x
+  pack [ttk::frame $w.b] -side top -fill x
   dialogbutton $w.b.go -text $::tr(FindNovelty) -command {
     destroy .noveltyWin
     progressWindow "Scid" "$::tr(FindNovelty)" $::tr(Cancel)
@@ -74,7 +61,7 @@ proc findNovelty {} {
   dialogbutton $w.b.close -textvar ::tr(Close) -command {
     catch {destroy .noveltyWin}
   }
-  packbuttons right $w.b.close $w.b.go
+  packdlgbuttons $w.b.close $w.b.go
   wm resizable $w 0 0
   focus $w.b.go
   bind $w <KeyPress-1> "$w.b1 invoke"
@@ -87,16 +74,16 @@ proc findNovelty {} {
 proc updateNoveltyWin {} {
   set w .noveltyWin
   if {! [winfo exists $w]} { return }
-  $w.older configure -text "$::tr(SelectOlderGames) (< [sc_game info date])"
+  $w.which.older configure -text "$::tr(SelectOlderGames) (< [sc_game info date])"
   catch { destroy $w.bases.del }
-  pack [frame $w.bases.del]
+  pack [frame $w.bases.del] -anchor w
   foreach i [sc_base list] {
     set name [file tail [sc_base filename $i]]
     set ng [::utils::thousands [sc_base numGames $i]]
     set txt "Base $i: $name ($ng $::tr(games))"
-    radiobutton $w.bases.del.b$i -text "$txt" -variable noveltyBase -value $i -underline 5
+    ttk::radiobutton $w.bases.del.b$i -text "$txt" -variable noveltyBase -value $i -underline 5
     if {$ng == 0} { $w.bases.del.b$i configure -state disabled }
-    pack $w.bases.del.b$i -side top -anchor w -padx 10
+    pack $w.bases.del.b$i -side top -anchor w -fill x
   }
 }
 
@@ -120,33 +107,36 @@ proc mergeGame {base gnum} {
   set merge(base) $base
   set merge(gnum) $gnum
   set w .mergeDialog
-  toplevel $w
+  win::createDialog $w
   wm title $w "Scid: $::tr(MergeGame)"
   bind $w <Escape> "$w.b.cancel invoke"
   bind $w <F1> {helpWindow GameList Browsing}
-  label $w.title -text $::tr(Preview:) -font font_Bold
-  pack $w.title -side top
-  pack [frame $w.b] -side bottom -fill x
-  frame $w.f
+  ttk::label $w.title -text $::tr(Preview:) -font font_Bold -anchor center
+  pack $w.title -side top -fill x
+  pack [ttk::frame $w.b] -side bottom -fill x
+  ttk::frame $w.f
   text $w.f.text -background white -wrap word -width 60 -height 20 \
       -font font_Small -yscrollcommand "$w.f.ybar set"
-  scrollbar $w.f.ybar -takefocus 0 -command "$w.f.text yview"
+  ttk::scrollbar $w.f.ybar -takefocus 0 -command "$w.f.text yview"
   event generate $w.f.text <ButtonRelease-1>
   pack $w.f.ybar -side right -fill y
   pack $w.f.text -side left -fill both -expand yes
   pack $w.f -fill both -expand yes
   set small font_Small
-  label $w.b.label -text "Up to move:" -font $small
+  ttk::label $w.b.label -text "Up to move:" -font $small
   pack $w.b.label -side left
-  foreach i {5 10 15 20 25 30 35 40} {
-    radiobutton $w.b.m$i -text $i -variable merge(ply) -value [expr {$i * 2}] \
-        -indicatoron 0 -padx 2 -pady 1 -font $small -command updateMergeGame
+  foreach i {5 10 15 20 25 30 35 40 500} {
+    if {$i != 500} {
+      set label $i
+      set label_width 3
+    } else {
+      set label [::utils::string::Capital $::tr(all)]
+      set label_width [string length $label]
+    }
+    ttk::button $w.b.m$i -text $label -width $label_width -padding 0 \
+      -command "updateMergeGame $w $i"
     pack $w.b.m$i -side left
   }
-  radiobutton $w.b.all -text [::utils::string::Capital $::tr(all)] \
-      -variable merge(ply) -value 1000 -indicatoron 0 -padx 2 -pady 1 \
-      -font $small -command updateMergeGame
-  pack $w.b.all -side left
   dialogbutton $w.b.ok -text "OK" -command {
     undoFeature save
     sc_game merge $merge(base) $merge(gnum) $merge(ply)
@@ -158,13 +148,19 @@ proc mergeGame {base gnum} {
       -command "catch {grab release $w}; destroy $w"
   packbuttons right $w.b.cancel $w.b.ok
   grab $w
-  updateMergeGame
+  updateMergeGame $w [expr $merge(ply) / 2]
 }
 
-proc updateMergeGame {args} {
+proc updateMergeGame {{w} {n_moves}} {
   global merge
-  set w .mergeDialog
   if {! [winfo exists $w]} { return }
+
+  # Update widgets
+  set widget [expr $merge(ply) / 2]
+  $w.b.m$widget state !pressed
+  $w.b.m$n_moves state pressed
+  set merge(ply) [expr {$n_moves * 2}];
+
   sc_game push copy
   sc_game merge $merge(base) $merge(gnum) $merge(ply)
   set pgn [sc_game pgn -indentV 1 -short 1 -width 60]
@@ -210,21 +206,21 @@ proc setExportText {exportType} {
   
   set w .setExportText$exportType
   if {[winfo exists $w]} { return }
-  toplevel $w
+  win::createDialog $w
   wm title $w "Scid: $title"
   
-  frame $w.buttons
+  ttk::frame $w.buttons
   pack $w.buttons -side bottom -fill x -anchor e
   
   set pane [::utils::pane::Create $w.pane start end 500 400]
   ::utils::pane::SetRange $w.pane 0.3 0.7
   pack $pane -side top -expand true -fill both
   foreach f [list $pane.start $pane.end] type {start end} {
-    label $f.title -font font_Bold -text "Text at $type of $exportType file:"
+    ttk::label $f.title -font font_Bold -text "Text at $type of $exportType file:"
     text $f.text -wrap none -background white \
         -yscroll "$f.ybar set" -xscroll "$f.xbar set"
-    scrollbar $f.ybar -orient vertical -command "$f.text yview"
-    scrollbar $f.xbar -orient horizontal -command "$f.text xview"
+    ttk::scrollbar $f.ybar -orient vertical -command "$f.text yview"
+    ttk::scrollbar $f.xbar -orient horizontal -command "$f.text xview"
     bind $f.text <FocusIn> {%W configure -background lightYellow}
     bind $f.text <FocusOut> {%W configure -background white}
     grid $f.title -row 0 -column 0 -sticky w
@@ -238,7 +234,7 @@ proc setExportText {exportType} {
   $pane.start.text insert end $exportStartFile($exportType)
   $pane.end.text insert end $exportEndFile($exportType)
   
-  button $w.buttons.default -text "Reset to Default" -command "
+  ttk::button $w.buttons.default -text "Reset to Default" -command "
   $pane.start.text delete 1.0 end
   $pane.start.text insert end \$default_exportStartFile($exportType)
   $pane.end.text delete 1.0 end
@@ -252,7 +248,7 @@ proc setExportText {exportType} {
   "
   dialogbutton $w.buttons.cancel -text $::tr(Cancel) -command "focus .; destroy $w"
   pack $w.buttons.default -side left -padx 5 -pady 2
-  pack $w.buttons.cancel $w.buttons.ok -side right -padx 5 -pady 2
+  packdlgbuttons $w.buttons.cancel $w.buttons.ok
   focus $pane.start.text
 }
 
@@ -327,7 +323,7 @@ proc exportOptions {exportType} {
   
   set w .exportFlagsWin
   set exportFlags(ok) -1
-  toplevel $w
+  win::createDialog $w
   wm title $w "Scid: [tr OptionsExport]"
   # wm transient $w .
   wm protocol $w WM_DELETE_WINDOW { }
@@ -335,111 +331,54 @@ proc exportOptions {exportType} {
   bind $w <Return> "$w.b.ok invoke"
   bind $w <F1> {helpWindow Export}
   
-  pack [frame $w.o] -side top -fill x -pady 5 -padx 5
-  label $w.o.append -text $::tr(AddToExistingFile)
-  radiobutton $w.o.appendYes -text $::tr(Yes) \
-      -variable exportFlags(append) -value 1
-  radiobutton $w.o.appendNo -text $::tr(No) \
-      -variable exportFlags(append) -value 0
-  label $w.o.comments -text $::tr(ExportComments)
-  radiobutton $w.o.commentsOn -text $::tr(Yes) \
-      -variable exportFlags(comments) -value 1
-  radiobutton $w.o.commentsOff -text $::tr(No) \
-      -variable exportFlags(comments) -value 0
-  label $w.o.stripMarks -text $::tr(ExportStripMarks)
-  radiobutton $w.o.stripMarksOn -text $::tr(Yes) \
-      -variable exportFlags(stripMarks) -value 1
-  radiobutton $w.o.stripMarksOff -text $::tr(No) \
-      -variable exportFlags(stripMarks) -value 0
-  label $w.o.indentc -text $::tr(IndentComments)
-  radiobutton $w.o.indentcOn -text $::tr(Yes) \
-      -variable exportFlags(indentc) -value 1
-  radiobutton $w.o.indentcOff -text $::tr(No) \
-      -variable exportFlags(indentc) -value 0
-  label $w.o.vars -text $::tr(ExportVariations)
-  radiobutton $w.o.varsOn -text $::tr(Yes) -variable exportFlags(vars) -value 1
-  radiobutton $w.o.varsOff -text $::tr(No) -variable exportFlags(vars) -value 0
-  label $w.o.indentv -text $::tr(IndentVariations)
-  radiobutton $w.o.indentvOn -text $::tr(Yes) \
-      -variable exportFlags(indentv) -value 1
-  radiobutton $w.o.indentvOff -text $::tr(No) \
-      -variable exportFlags(indentv) -value 0
-  label $w.o.column -text $::tr(ExportColumnStyle)
-  radiobutton $w.o.columnOn -text $::tr(Yes) \
-      -variable exportFlags(column) -value 1
-  radiobutton $w.o.columnOff -text $::tr(No) \
-      -variable exportFlags(column) -value 0
-  label $w.o.symbols -text $::tr(ExportSymbolStyle)
-  radiobutton $w.o.symbolsOn -text "! +=" \
-      -variable exportFlags(symbols) -value 1
-  radiobutton $w.o.symbolsOff -text {$2 $14} \
-      -variable exportFlags(symbols) -value 0
+  pack [ttk::frame $w.o] -side top -fill x
+  ttk::checkbutton $w.o.append -variable exportFlags(append) -offvalue 0 -onvalue 1 -textvar ::tr(AddToExistingFile)
+  ttk::checkbutton $w.o.comments -variable exportFlags(comments) -offvalue 0 -onvalue 1 -textvar ::tr(ExportComments)
+  ttk::checkbutton $w.o.stripMarks -variable exportFlags(stripMarks) -offvalue 0 -onvalue 1 -textvar ::tr(ExportStripMarks)
+  ttk::checkbutton $w.o.indentc -variable exportFlags(indentc) -offvalue 0 -onvalue 1 -textvar ::tr(IndentComments)
+  ttk::checkbutton $w.o.vars -variable exportFlags(vars) -offvalue 0 -onvalue 1 -textvar ::tr(ExportVariations)
+  ttk::checkbutton $w.o.indentv -variable exportFlags(indentv) -offvalue 0 -onvalue 1 -textvar ::tr(IndentVariations)
+  ttk::checkbutton $w.o.column -variable exportFlags(column) -offvalue 0 -onvalue 1 -textvar ::tr(ExportColumnStyle)
+  ttk::checkbutton $w.o.symbols -variable exportFlags(symbols) -offvalue 0 -onvalue 1 -text "$::tr(ExportSymbolStyle) ! +="
   grid $w.o.append -row 0 -column 0 -sticky w
-  grid $w.o.appendYes -row 0 -column 1 -sticky w
-  grid $w.o.appendNo -row 0 -column 2 -sticky w
   grid $w.o.comments -row 1 -column 0 -sticky w
-  grid $w.o.commentsOn -row 1 -column 1 -sticky w
-  grid $w.o.commentsOff -row 1 -column 2 -sticky w
   grid $w.o.stripMarks -row 2 -column 0 -sticky w
-  grid $w.o.stripMarksOn -row 2 -column 1 -sticky w
-  grid $w.o.stripMarksOff -row 2 -column 2 -sticky w
   grid $w.o.indentc -row 3 -column 0 -sticky w
-  grid $w.o.indentcOn -row 3 -column 1 -sticky w
-  grid $w.o.indentcOff -row 3 -column 2 -sticky w
   grid $w.o.vars -row 4 -column 0 -sticky w
-  grid $w.o.varsOn -row 4 -column 1 -sticky w
-  grid $w.o.varsOff -row 4 -column 2 -sticky w
   grid $w.o.indentv -row 5 -column 0 -sticky w
-  grid $w.o.indentvOn -row 5 -column 1 -sticky w
-  grid $w.o.indentvOff -row 5 -column 2 -sticky w
   grid $w.o.column -row 6 -column 0 -sticky w
-  grid $w.o.columnOn -row 6 -column 1 -sticky w
-  grid $w.o.columnOff -row 6 -column 2 -sticky w
   grid $w.o.symbols -row 7 -column 0 -sticky w
-  grid $w.o.symbolsOn -row 7 -column 1 -sticky w
-  grid $w.o.symbolsOff -row 7 -column 2 -sticky w
   
   # Extra option for PGN format: handling of null moves
   if {$exportType == "PGN"} {
-    label $w.o.space -text ""
-    grid $w.o.space -row 8 -column 0 -sticky w
-    label $w.o.nullMoves -text "Convert null moves to comments"
-    radiobutton $w.o.convertNullMoves -text $::tr(Yes) \
-        -variable exportFlags(convertNullMoves) -value 1
-    radiobutton $w.o.keepNullMoves -text $::tr(No) \
-        -variable exportFlags(convertNullMoves) -value 0
-    grid $w.o.nullMoves -row 9 -column 0 -sticky w
-    grid $w.o.convertNullMoves -row 9 -column 1 -sticky w
-    grid $w.o.keepNullMoves -row 9 -column 2 -sticky w
+    ttk::checkbutton $w.o.nullMoves -variable exportFlags(convertNullMoves) -offvalue 0 -onvalue 1 -textvar ::tr(ConvertNullMove)
+    grid $w.o.nullMoves -row 8 -column 0 -sticky w
   }
   
   # Extra option for HTML format: diagram image set
   if {$exportType == "HTML"} {
-    label $w.o.space -text ""
-    label $w.o.hdiag -text "Diagram"
-    radiobutton $w.o.hb0 -text "bitmaps" \
+    ttk::label $w.o.hdiag -text "Diagram"
+    ttk::radiobutton $w.o.hb0 -text "bitmaps" \
         -variable exportFlags(htmldiag) -value 0
-    radiobutton $w.o.hb1 -text "bitmaps2" \
+    ttk::radiobutton $w.o.hb1 -text "bitmaps2" \
         -variable exportFlags(htmldiag) -value 1
-    label $w.o.hl0 -image htmldiag0
-    label $w.o.hl1 -image htmldiag1
-    grid $w.o.space -row 8 -column 0
-    grid $w.o.hdiag -row 9 -column 0 -sticky w
-    grid $w.o.hb0 -row 9 -column 1 -sticky w
-    grid $w.o.hb1 -row 9 -column 2 -sticky w
-    grid $w.o.hl0 -row 10 -column 1
-    grid $w.o.hl1 -row 10 -column 2
+    ttk::label $w.o.hl0 -image htmldiag0
+    ttk::label $w.o.hl1 -image htmldiag1
+    grid $w.o.hdiag -row 8 -column 0 -sticky w
+    grid $w.o.hb0 -row 9 -column 0 -sticky w
+    grid $w.o.hb1 -row 9 -column 1 -sticky w
+    grid $w.o.hl0 -row 10 -column 0 -sticky w
+    grid $w.o.hl1 -row 10 -column 1 -sticky w
   }
   
-  addHorizontalRule $w
-  pack [frame $w.b] -side top
+  pack [ttk::frame $w.b] -side top -fill x
   dialogbutton $w.b.ok -text "OK" -command {
     set exportFlags(ok) 1
   }
   dialogbutton $w.b.cancel -text $::tr(Cancel) -command {
     set exportFlags(ok) 0
   }
-  pack $w.b.ok $w.b.cancel -side left -padx 5 -pady 5
+  packbuttons right $w.b.cancel $w.b.ok
   
   wm withdraw $w
   update idletasks
@@ -642,19 +581,18 @@ proc nameEditor {} {
     destroy $w
     return
   }
-  toplevel $w
+  win::createDialog $w
   wm title $w "Scid: [tr FileMaintNameEditor]"
   set nameEditorWin 1
   setWinLocation $w
   bind $w <Configure> "recordWinSize $w"
-  
-  label $w.typeLabel -textvar ::tr(NameEditType:) -font font_Bold
-  frame $w.typeButtons
-  pack $w.typeLabel $w.typeButtons -side top -pady 5
-  foreach i { "Player" "Event" "Site" "Round"} {
+
+  ttk::labelframe $w.typeButtons -text $::tr(NameEditType)
+  pack $w.typeButtons -side top -fill x -anchor w
+  foreach i { "Player" "Event" "Site" "Round"} col {0 1 2 3} {
     set j [string tolower $i]
-    radiobutton $w.typeButtons.$j -textvar ::tr($i) -variable editNameType \
-        -value $j -indicatoron false -pady 5 -padx 5 -command {
+    ttk::radiobutton $w.typeButtons.$j -textvar ::tr($i) -variable editNameType \
+        -value $j -command {
           grid remove .nedit.g.ratingE
           grid remove .nedit.g.rtype
           grid remove .nedit.g.fromD
@@ -663,10 +601,10 @@ proc nameEditor {} {
           grid .nedit.g.fromE -row 0 -column 2 -sticky w
           grid .nedit.g.toE -row 1 -column 2 -sticky w
         }
-    pack $w.typeButtons.$j -side left -padx 5
+    grid $w.typeButtons.$j -row 1 -column $col -sticky w -padx "0 5"
   }
-  radiobutton $w.typeButtons.rating -textvar ::tr(Rating) -variable editNameType \
-      -value rating -indicatoron false -pady 5 -padx 5 -command {
+  ttk::radiobutton $w.typeButtons.rating -textvar ::tr(Rating) -variable editNameType \
+      -value rating -command {
         grid remove .nedit.g.toE
         grid remove .nedit.g.toL
         grid remove .nedit.g.fromD
@@ -675,8 +613,9 @@ proc nameEditor {} {
         grid .nedit.g.rtype -row 1 -column 0 -columnspan 2 -sticky e
         grid .nedit.g.ratingE -row 1 -column 2 -sticky w
       }
-  radiobutton $w.typeButtons.date -textvar ::tr(Date) -variable editNameType \
-      -value date -indicatoron false -pady 5 -padx 5 -command {
+  grid $w.typeButtons.rating -row 2 -column 0  -columnspan 2 -sticky w
+  ttk::radiobutton $w.typeButtons.date -textvar ::tr(Date) -variable editNameType \
+      -value date -command {
         grid remove .nedit.g.toE
         grid remove .nedit.g.fromE
         grid remove .nedit.g.ratingE
@@ -685,8 +624,9 @@ proc nameEditor {} {
         grid .nedit.g.toL -row 1 -column 1 -sticky e
         grid .nedit.g.toD -row 1 -column 2 -sticky w
       }
-  radiobutton $w.typeButtons.edate -textvar ::tr(EventDate) \
-      -variable editNameType -value edate -indicatoron false -pady 5 -padx 5 \
+  grid $w.typeButtons.date -row 2 -column 1 -sticky w -padx "0 5"
+  ttk::radiobutton $w.typeButtons.edate -textvar ::tr(EventDate) \
+      -variable editNameType -value edate \
       -command {
         grid remove .nedit.g.toE
         grid remove .nedit.g.fromE
@@ -696,60 +636,48 @@ proc nameEditor {} {
         grid .nedit.g.toL -row 1 -column 1 -sticky e
         grid .nedit.g.toD -row 1 -column 2 -sticky w
       }
-  pack $w.typeButtons.rating $w.typeButtons.date $w.typeButtons.edate \
-      -side left -padx 5
-  
-  addHorizontalRule .nedit
-  
-  label $w.selectLabel -textvar ::tr(NameEditSelect) -font font_Bold
-  frame $w.selectButtons
-  pack $w.selectLabel $w.selectButtons -side top -pady 5
+  grid $w.typeButtons.edate -row 2 -column 2 -sticky w -columnspan 2
+
+  ttk::labelframe $w.selectButtons -text $::tr(NameEditSelect)
+  pack $w.selectButtons -side top -fill x -pady 10
   foreach i {all filter crosstable} row {0 1 2} text {
     SelectAllGames
     SelectFilterGames
     SelectTournamentGames
   } {
-    radiobutton $w.selectButtons.$i -textvar ::tr($text) \
+    ttk::radiobutton $w.selectButtons.$i -textvar ::tr($text) \
         -variable editNameSelect -value $i
     grid $w.selectButtons.$i -row $row -column 0 -sticky w
   }
   
-  addHorizontalRule $w
-  
-  pack [frame $w.g] -side top
-  label $w.g.space -text "    "
-  grid $w.g.space $w.g.space -row 0 -column 0
-  label $w.g.fromL -textvar ::tr(NameEditReplace:) -font font_Bold -anchor e
-  entry $w.g.fromE -width 40 -background white -relief sunken \
-      -textvariable editName
-  entry $w.g.fromD -width 15 -background white -relief sunken \
-      -textvariable editDate
+  pack [ttk::frame $w.g] -side top -fill x
+  ttk::label $w.g.fromL -textvar ::tr(NameEditReplace:) -font font_Bold -anchor e
+  ttk::entry $w.g.fromE -width 40 -textvariable editName
+  ttk::entry $w.g.fromD -width 15 -textvariable editDate
   grid $w.g.fromL -row 0 -column 1 -sticky e
   grid $w.g.fromE -row 0 -column 2 -sticky we
   
-  label $w.g.toL -textvar ::tr(NameEditWith:) -font font_Bold -anchor e
-  entry $w.g.toE -width 40 -background white -relief sunken \
-      -textvariable editNameNew
-  entry $w.g.toD -width 15 -background white -relief sunken \
-      -textvariable editDateNew
+  ttk::label $w.g.toL -textvar ::tr(NameEditWith:) -font font_Bold -anchor e
+  ttk::entry $w.g.toE -width 40 -textvariable editNameNew
+  ttk::entry $w.g.toD -width 15 -textvariable editDateNew
   grid $w.g.toL -row 1 -column 1 -sticky e
   grid $w.g.toE -row 1 -column 2 -sticky we
   
-  entry $w.g.ratingE -width 5 -background white -relief sunken \
-      -textvariable editNameRating -justify right
-  eval tk_optionMenu $w.g.rtype editNameRType [sc_info ratings]
-  $w.g.rtype configure -pady 2
+  ttk::entry $w.g.ratingE -width 5 -textvariable editNameRating -justify right
+  set mlist [split [sc_info ratings] " "]
+  ttk::menubutton $w.g.rtype -textvariable editNameRType -menu $w.g.rtype.menu
+  menu $w.g.rtype.menu
+  foreach m $mlist {
+      $w.g.rtype.menu add radiobutton -variable editNameRType -label $m
+  }
   
-  label $w.g.title -textvar ::tr(NameEditMatches) \
+  ttk::label $w.g.title -textvar ::tr(NameEditMatches) \
       -font font_Bold
   text $w.g.list -height 9 -width 40 -relief sunken \
       -background grey90 -tabs {2c right 2.5c left} -wrap none
   
-  label $w.g.padding -text ""
-  grid $w.g.padding -row 2 -column 0
-  
-  grid $w.g.title -row 3 -column 1 -columnspan 2 -sticky n
-  grid $w.g.list -row 4 -column 1 -rowspan 9 -columnspan 2 -sticky n
+  grid $w.g.title -row 2 -column 1 -columnspan 2 -sticky n
+  grid $w.g.list -row 3 -column 1 -rowspan 9 -columnspan 2 -sticky e
   
   updateMatchList $w.g.list "" 9 editName "" w
   
@@ -765,10 +693,8 @@ proc nameEditor {} {
     }
   }
   
-  addHorizontalRule $w
-  
-  frame $w.buttons
-  button $w.buttons.replace -textvar ::tr(NameEditReplace) -command {
+  ttk::frame $w.buttons
+  ttk::button $w.buttons.replace -textvar ::tr(NameEditReplace) -command {
     if {$editNameType == "rating"} {
       set err [catch {sc_name edit $editNameType $editNameSelect $editName $editNameRating $editNameRType} result]
     } elseif {$editNameType == "date"  ||  $editNameType == "edate"} {
@@ -779,7 +705,7 @@ proc nameEditor {} {
     if {$err} {
       ERROR::MessageBox
     } else {
-      .nedit.status configure -text $result
+      .nedit.status configure -text "Modified $result games."
     }
     sc_game tags reload
     updateBoard -pgn
@@ -787,10 +713,10 @@ proc nameEditor {} {
   }
   
   dialogbutton $w.buttons.cancel -textvar ::tr(Close) -command {focus .; destroy .nedit}
-  pack $w.buttons -side top -pady 5
-  pack $w.buttons.replace $w.buttons.cancel -side left -padx 10
+  pack $w.buttons -fill x
+  packdlgbuttons $w.buttons.cancel $w.buttons.replace
   
-  label $w.status -text "" -width 1 -font font_Small -relief sunken -anchor w
+  ttk::label $w.status -text "" -width 1 -font font_Small -relief sunken -anchor w
   pack $w.status -side bottom -fill x
   
   wm resizable $w 0 0
@@ -826,12 +752,11 @@ proc gameSave { gnum } {
   # Make a new toplevel that contains the game save dialog:
   set w .save
   if {[winfo exists $w]} { return }
-  toplevel $w
+  win::createDialog $w
   if {$gnum == 0} {
     wm title $w "Scid: [tr GameAdd]"
-    pack [ttk::frame $w.refdb] -side top -fill x
+    pack [ttk::frame $w.refdb] -side top -fill x -pady {0 10}
     CreateSelectDBWidget "$w.refdb" "gameSave_toBase" [sc_base current] 0
-    addHorizontalRule $w
   } else {
     wm title $w "Scid: [tr GameReplace]"
   }
@@ -839,7 +764,7 @@ proc gameSave { gnum } {
   catch {grab $w}
   
   set f [ttk::frame $w.g]
-  pack $f -side top
+  pack $f -side top -anchor w
   
   ttk::label $f.title -textvar ::tr(NameEditMatches)
   text $f.list -height 9 -width 40 -relief sunken -background grey90 \
@@ -943,11 +868,14 @@ proc gameSave { gnum } {
   addGameSaveEntry black 6 ::tr(Black:)
   
   ttk::label $f.reslabel -textvar ::tr(Result:)
-  ttk::entry $f.resentry -width 2 -textvariable resultVal
-  ttk::label $f.rescomment -text "(1, =, 0, *)"
+  ttk::frame $f.resentry
+  ttk::radiobutton $f.resentry.w -text "1-0  " -variable resultVal -value 1
+  ttk::radiobutton $f.resentry.b -text "0-1  " -variable resultVal -value 0
+  ttk::radiobutton $f.resentry.r -text "1/2-1/2  " -variable resultVal -value =
+  ttk::radiobutton $f.resentry.u -text "*" -variable resultVal -value *
+  pack $f.resentry.w $f.resentry.b $f.resentry.r $f.resentry.u -side left 
   grid $f.reslabel -row 7 -column 0 -sticky w
-  grid $f.resentry -row 7 -column 1 -sticky w
-  grid $f.rescomment -row 7 -column 2 -columnspan 4 -sticky w
+  grid $f.resentry -row 7 -column 1 -sticky w -columnspan 4
   
   ttk::label $f.welolabel -text "$::tr(White) "
   
@@ -976,25 +904,21 @@ proc gameSave { gnum } {
   ttk::button $f.ecob -textvar ::tr(ClassifyGame) -command {set eco [sc_eco game]}
   grid $f.ecob -row 10 -column 2 -sticky w
   
-  grid $f.title -row 0 -column 8 -sticky n -padx 10
-  grid $f.list -row 1 -column 8 -rowspan 9 -sticky nw -padx 10
+  grid $f.title -row 0 -column 8 -sticky w  -padx "10 0"
+  grid $f.list -row 1 -column 8 -rowspan 9 -sticky nw -padx "10 0"
   
-  addHorizontalRule .save
-  
-  ttk::label .save.extralabel -text "Extra Tags: (example format: Annotator \"Anand, V\") "
-  pack .save.extralabel -side top -fill x
-  ttk::frame .save.extra
+  ttk::labelframe .save.extra -text "Extra Tags: (example format: Annotator \"Anand, V\") "
+  pack .save.extra -side top -fill both -expand 1
   text .save.extra.text -height 4 -width 40 -bg white -wrap none \
       -yscrollcommand ".save.extra.scroll set"
   # Override tab-binding for this text widget:
   bind .save.extra.text <Key-Tab> "[bind all <Key-Tab>]; break"
   ttk::scrollbar .save.extra.scroll -command ".save.extra.text yview" -takefocus 0
-  ttk::button .save.extra.last -text "Use\nlast\ngame's\ntags" -command {
+  ttk::button .save.extra.last -text $::tr(UseLastTag) -command {
     set extraTags [sc_game tag get -last Extra]
     .save.extra.text delete 1.0 end
     .save.extra.text insert 1.0 $extraTags
   }
-  pack .save.extra -side top -fill both -expand 1 -ipady 10
   pack .save.extra.text -side left -fill both -expand 1
   if {$gnum == 0} {
     pack .save.extra.last -side right -padx 10
@@ -1026,8 +950,6 @@ proc gameSave { gnum } {
     }
   }
   
-  addHorizontalRule .save
-  
   ttk::frame .save.buttons
   if {$gnum == 0} {
     ttk::button .save.buttons.prev -text "As last game" -command {
@@ -1044,11 +966,11 @@ proc gameSave { gnum } {
   # bind .save <Alt-s> { .save.buttons.save invoke; break }
   
   dialogbutton .save.buttons.cancel -textvar ::tr(Cancel) -command {destroy .save}
-  pack .save.buttons -side bottom -ipady 10 -fill both -expand 1
+  pack .save.buttons -side bottom -padx 10 -fill both -expand 1
   if {$gnum == 0} {
     #pack .save.buttons.prev -side left -padx 10
   }
-  packbuttons right .save.buttons.cancel .save.buttons.save
+  packdlgbuttons .save.buttons.cancel .save.buttons.save
   
   bind .save <Escape> { focus .; destroy .save; }
   ::utils::win::Centre .save
@@ -1079,11 +1001,12 @@ proc gsave { gnum } {
     ::notify::DatabaseModified [sc_base current]
     ::notify::GameChanged
   } else {
-    set ply [sc_pos location]
+    set ply [sc_pos pgnOffset]
     if { [catch {sc_game save $gnum $::gameSave_toBase}] } { return 0 }
     ::notify::DatabaseModified $::gameSave_toBase
     ::file::SwitchToBase $::gameSave_toBase 0
-    ::game::Load [sc_base numGames $::gameSave_toBase] $ply
+    ::game::Load [sc_base numGames $::gameSave_toBase]
+    ::move::PGNOffset $ply
   }
   return 1
 }
@@ -1114,60 +1037,25 @@ proc helpAbout {} {
   set str {}
   append str "Scid: Shane's chess information database\n\n"
   append str "Version $::scidVersion, $::scidVersionDate\n"
-  append str "Using Tcl/Tk version: [info patchlevel]\n\n"
   append str "Copyright (C) 1999-2004 Shane Hudson\n"
   append str "Copyright (C) 2006-2009 Pascal Georges\n"
   append str "Copyright (C) 2008-2011 Alexander Wagner\n"
   append str "Copyright (C) 2011 Gerd Lorscheid\n"
-  append str "Copyright (C) 2009-2015 Fulvio Benini\n"
+  append str "Copyright (C) 2009-2019 Fulvio Benini\n"
   append str "\nScid is licenced under the\n"
   append str "GNU General Public License.\n"
 
+  append str "\n\nUsing Tcl/Tk version: [info patchlevel]\n"
+  append str "Loaded packages:\n"
+  foreach {pkg} [lsort [package names]] {
+    set ver [package provide $pkg]
+    if {$ver != ""} { append str "$pkg\($ver),  " }
+  }
+  regsub ",  $" $str "." str
+
   tk_messageBox -title "About Scid" -message $str -type ok
 }
 
-############################################################
-#### Square Bindings:
-# Pascal Georges : allow the drawing of markers directly on the board (not through comment editor)
-set startArrowSquare ""
-
-proc addMarker {sq color} {
-  set to [::board::san $sq]
-  set oldComment [sc_pos getComment]
-  
-  # check if the square is already of the same color
-  set erase [regexp "\[\x5B\]%draw full,$to,$color\[\x5D\]" $oldComment]
-  regsub "\[\x5B\]%draw full,$to,(green|yellow|red)\[\x5D\]" $oldComment "" newComment
-  set newComment [string trim $newComment]
-  if {!$erase} {
-    append newComment " \[%draw full,$to,$color\]"
-  }
-  sc_pos setComment $newComment
-  ::pgn::Refresh 1
-  updateBoard
-}
-
-proc drawArrow {sq color} {
-  global startArrowSquare
-  if {$startArrowSquare == ""} {
-    set startArrowSquare [::board::san $sq]
-  } else  {
-    set oldComment [sc_pos getComment]
-    set to [::board::san $sq]
-    if {$startArrowSquare != $to } {
-      set erase [regexp "\[\x5B\]%draw arrow,$startArrowSquare,$to,$color\[\x5D\]" $oldComment]
-      regsub "\[\x5B\]%draw arrow,$startArrowSquare,$to,(green|yellow|red)\[\x5D\]" $oldComment "" newComment
-      set newComment [string trim $newComment]
-      if {!$erase} {
-        append newComment " \[%draw arrow,$startArrowSquare,$to,$color\]"
-      }
-      sc_pos setComment $newComment
-      ::pgn::Refresh 1
-      updateBoard
-    }
-    set startArrowSquare ""
-  }
-}
 
 proc MouseWheelRedirector {W X Y D} {
     # Generate an MWheel virtual event to the window that has the mouse pointer
@@ -1362,11 +1250,6 @@ proc showHideAllWindows {type} {
   
   # Now iconify/deiconify all the major Scid windows that exist:
   foreach w [getTopLevel] {
-    # .baseWin .glistWin .pgnWin .tourney .maintWin \
-    # .ecograph .crosstabWin .treeWin .analysisWin1 .anslysisWin2 \
-    # .playerInfoWin .commentWin .repWin .statsWin .tbWin \
-    # .sb .sh .sm .noveltyWin .emailWin .oprepWin .plist \
-    # .rgraph .sgraph .importWin .helpWin .tipsWin
     if {[winfo exists $w]} { catch {wm $type $w} }
   }
   
@@ -1379,53 +1262,28 @@ proc raiseAllWindows {} {
   showHideAllWindows deiconify
   
   foreach w [getTopLevel] {
-    # .baseWin .glistWin .pgnWin .tourney .maintWin \
-    # .ecograph .crosstabWin .treeWin .analysisWin1 .anslysisWin2 \
-    # .playerInfoWin .commentWin .repWin .statsWin .tbWin \
-    # .sb .sh .sm .noveltyWin .emailWin .oprepWin .plist \
-    # .rgraph .sgraph .importWin .helpWin .tipsWin
     if {[winfo exists $w]} { catch { raise $w } }
   }
 }
 
-proc CreateMainWin { mainWin } {
-  createToplevel .main
-  wm minsize $mainWin 0 0
-  wm iconname $mainWin "Scid"
-  wm protocol $mainWin WM_DELETE_WINDOW { ::file::Exit }
-  $mainWin configure -menu .menu
-  setWinLocation $mainWin
-  bind $mainWin <Configure> "recordWinSize $mainWin"
-  CreateGameInfo
-  CreateMainBoard .main
-}
+# Disable ttk default left/right key bindings (they invoke ttk::notebook::CycleTab)
+bind TNotebook <Key-Right> {}
+bind TNotebook <Key-Left>  {}
 
-if { $::docking::USE_DOCKING } {
-  CreateMainWin .
-  ::docking::layout_restore 1
-  keyboardShortcuts TPanedwindow
-  keyboardShortcuts TNotebook
-} else {
-  CreateMainWin .main
-  if {$startup(switcher)} { ::windows::switcher::Open }
-  if {$startup(pgn)} { ::pgn::OpenClose }
-  if {$startup(gamelist)} { ::windows::gamelist::Open }
-  if {$startup(tree)} { ::tree::make }
-  if {$startup(crosstable)} { crosstabWin }
-  if {$startup(book)} { ::book::open }
-}
-if {$startup(stats)} { ::windows::stats::Open }
-if {$startup(tip)} { ::tip::show }
-if {$startup(finder)} { ::file::finder::Open }
+wm iconname . "Scid"
+wm protocol . WM_DELETE_WINDOW { ::file::Exit }
+setMenu . .menu
+keyboardShortcuts .
+
+::docking::layout_restore 1
 
 menuUpdateBases
+menuUpdateThemes
 setLanguageMenus
 
-update
-update idletasks
-
-#keyboardShortcuts hack
-bind . <FocusIn> { if {[string equal %W "."]} { focus .main } }
+if {$startup(stats)} { ::windows::stats::Open }
+if {$startup(finder)} { ::file::finder::Open }
+if {$startup(tip)} { ::tip::show }
 
 # Try to load the spellcheck file:
 if {$loadAtStart(spell)} {
