@@ -48,7 +48,7 @@ menuText E FileNew "New..." 0 {Create a new Scid database}
 menuText E FileOpen "Open..." 0 {Open an existing Scid database}
 menuText E FileClose "Close" 0 {Close the active Scid database}
 menuText E FileFinder "Finder" 0 {Open the File Finder window}
-menuText E FileBookmarks "Bookmarks" 0 {Bookmarks menu (shortcut: Ctrl+B)}
+menuText E FileBookmarks "Bookmarks" 0 {Bookmarks menu}
 menuText E FileBookmarksAdd "Add Bookmark" 0 \
   {Bookmark the current database game and position}
 menuText E FileBookmarksFile "File Bookmark" 0 \
@@ -127,8 +127,7 @@ menuText E EditPasteBoard "Paste Start Board" 12 \
 
 # Game menu:
 menuText E Game "Game" 0
-menuText E GameNew "New Game" 0 \
-  {Reset to an empty game, discarding any changes}
+menuText E GameNew "New Game" 0 {Reset to an empty game}
 menuText E GameFirst "Load First Game" 5 {Load the first filtered game}
 menuText E GamePrev "Load Previous Game" 5 {Load the previous filtered game}
 menuText E GameReload "Re-Load Current Game" 3 \
@@ -332,9 +331,15 @@ menuText E OptionsTable "Tablebase Directory..." 10 \
 menuText E OptionsRecent "Recent Files..." 0 {Change the number of recent files displayed in the File menu}
 menuText E OptionsBooksDir "Books directory..." 0 {Sets the opening books directory}
 menuText E OptionsTacticsBasesDir "Bases directory..." 0 {Sets the tactics (training) bases directory}
+menuText E OptionsPhotosDir "Photos directory..." 0 {Sets the photos bases directory}
+menuText E OptionsThemeDir "Load Theme(s)..."  0 { Load a GUI theme package file }
 menuText E OptionsSave "Save Options" 0 "Save all settable options to the file $::optionsFile"
 menuText E OptionsAutoSave "Auto-Save Options on Exit" 0 \
   {Auto-save all options when exiting Scid}
+menuText E OptionsMenuColor "Setup Menu Colors..." 0 { }
+translate E MenuColorForeground "Textcolor"
+translate E MenuColorBackground "Background"
+translate E MenuColorSelect "Select"
 
 # Help menu:
 menuText E Help "Help" 0
@@ -426,7 +431,8 @@ translate E Year {Year}
 translate E Month {Month}
 translate E Months {January February March April May June July August September October November December}
 translate E Days {Sun Mon Tue Wed Thu Fri Sat}
-translate E YearToToday {Year to today}
+translate E YearToToday {-1Y}
+translate E YearToTodayTooltip {Set date from 1 year back to today}
 translate E Result {Result}
 translate E Round {Round}
 translate E Length {Length}
@@ -472,6 +478,7 @@ translate E PInfoMostBlack {Most common openings as Black}
 translate E PInfoRating {Rating history}
 translate E PInfoBio {Biography}
 translate E PInfoEditRatings {Edit Ratings}
+translate E PInfoEloFile {File}
 
 # Tablebase information:
 translate E Draw {Draw}
@@ -490,6 +497,14 @@ translate E WinningMoves {Winning moves}
 translate E DrawingMoves {Drawing moves}
 translate E LosingMoves {Losing moves}
 translate E UnknownMoves {Unknown-result moves}
+translate E SideLongest {Side    Longest    %     %     %\n}
+translate E toNoveMate {to move   mate    Win  Draw  Loss\n}
+translate E NoSummary {\nNo summary for this tablebase.}
+translate E MutualZugzwang {Mutual zugzwangs: }
+translate E SelectetZugzwang {\nSelected zugzwang positions:}
+translate E WdrawBloss {White draws, Black loses:}
+translate E BdrawWloss {Black draws, White loses:}
+translate E AllLoss {" Whoever moves loses:     " }
 
 # Tip of the day:
 translate E Tip {Tip}
@@ -646,6 +661,8 @@ menuText E GraphOptionsWhite "White" 0
 menuText E GraphOptionsBlack "Black" 0
 menuText E GraphOptionsBoth "Both" 1
 menuText E GraphOptionsPInfo "Player Info player" 0
+menuText E GraphOptionsEloFile "Elo from rating file" 0
+menuText E GraphOptionsEloDB "Elo from database" 0
 translate E GraphFilterTitle "Filter Graph: frequency per 1000 games"
 translate E GraphAbsFilterTitle "Filter Graph: frequency of the games"
 translate E ConfigureFilter "Configure X-Axes for Year, Rating and Moves"
@@ -665,7 +682,7 @@ translate E StartEngine {Start engine}
 translate E LockEngine {Lock engine to current position}
 translate E AnalysisCommand {Analysis Command}
 translate E PreviousChoices {Previous Choices}
-translate E AnnotateTime {Set the time between moves in seconds}
+translate E AnnotateTime {Time per move in sec.}
 translate E AnnotateWhich {Add variations}
 translate E AnnotateAll {For moves by both sides}
 translate E AnnotateAllMoves {Annotate all moves}
@@ -704,12 +721,6 @@ translate E EngineNew {New}
 translate E EngineEdit {Edit}
 translate E EngineRequired {Fields in bold are required; others are optional}
 
-# Stats window menus:
-menuText E StatsFile "File" 0
-menuText E StatsFilePrint "Print to File..." 0
-menuText E StatsFileClose "Close Window" 0
-menuText E StatsOpt "Options" 0
-
 # PGN window menus:
 menuText E PgnFile "File" 0
 menuText E PgnFileCopy "Copy Game to Clipboard" 0
@@ -940,7 +951,6 @@ translate E StripTag {Strip tag}
 translate E Cleaner {Cleaner}
 translate E CleanerHelp {
 The Scid Cleaner will perform all the maintenance actions you select from the list below, on the current database.
-
 Current settings in the ECO classification and twin deletion dialogs will apply if you select those functions.
 }
 translate E CleanerConfirm {
@@ -968,7 +978,7 @@ translate E TwinCriteria3 {It is recommended that you specify "Yes" for at least
 translate E TwinCriteriaConfirm {Scid: Confirm twin settings}
 translate E TwinChangeTag "Change the following game tags:\n\n"
 translate E AllocRatingDescription "This command will use the current spellcheck file to add Elo ratings to games in this database. Wherever a player has no current rating but his/her rating at the time of the game is listed in the spellcheck file, that rating will be added."
-translate E RatingOverride "Overwrite existing non-zero ratings?"
+translate E RatingOverride "Overwrite existing non-zero ratings"
 translate E AddRatings "Add ratings to:"
 translate E AddedRatings {Scid added $r Elo ratings in $g games.}
 
@@ -1079,7 +1089,7 @@ translate E ClearFen {Clear FEN}
 translate E PasteFen {Paste FEN}
 
 translate E SaveAndContinue {Save and continue}
-translate E DiscardChangesAndContinue {Discard changes\nand continue}
+translate E DiscardChangesAndContinue {Discard changes and continue}
 translate E GoBack {Go back}
 
 # Replace move dialog:
@@ -1224,26 +1234,26 @@ translate E SelectOlderGames {Only older games}
 translate E TwinsNote {To be twins, two games must at least have the same two players, and criteria you can set below. When a pair of twins is found, the shorter game is deleted. Hint: it is best to spellcheck the database before deleting twins, since it improves twin detection. }
 translate E TwinsCriteria {Criteria: Twin games must have...}
 translate E TwinsWhich {Examine which games}
-translate E TwinsColors {Same player colors?}
-translate E TwinsEvent {Same event?}
-translate E TwinsSite {Same site?}
-translate E TwinsRound {Same round?}
-translate E TwinsYear {Same year?}
-translate E TwinsMonth {Same month?}
-translate E TwinsDay {Same day?}
-translate E TwinsResult {Same result?}
-translate E TwinsECO {Same ECO code?}
-translate E TwinsMoves {Same moves?}
-translate E TwinsPlayers {Comparing player names:}
+translate E TwinsColors {Same player colors}
+translate E TwinsEvent {Same event}
+translate E TwinsSite {Same site}
+translate E TwinsRound {Same round}
+translate E TwinsYear {Same year}
+translate E TwinsMonth {Same month}
+translate E TwinsDay {Same day}
+translate E TwinsResult {Same result}
+translate E TwinsECO {Same ECO code}
+translate E TwinsMoves {Same moves}
+translate E TwinsPlayers {Comparing player names}
 translate E TwinsPlayersExact {Exact match}
 translate E TwinsPlayersPrefix {First 4 letters only}
 translate E TwinsWhen {When deleting twin games}
-translate E TwinsSkipShort {Ignore all games under 5 moves long?}
-translate E TwinsUndelete {Undelete all games first?}
-translate E TwinsSetFilter {Set filter to all deleted twin games?}
-translate E TwinsComments {Always keep games with comments?}
-translate E TwinsVars {Always keep games with variations?}
-translate E TwinsDeleteWhich {Delete which game:}
+translate E TwinsSkipShort {Ignore all games under 5 moves long}
+translate E TwinsUndelete {Undelete all games first}
+translate E TwinsSetFilter {Set filter to all deleted twin games}
+translate E TwinsComments {Always keep games with comments}
+translate E TwinsVars {Always keep games with variations}
+translate E TwinsDeleteWhich {Delete game}
 translate E TwinsDeleteShorter {Shorter game}
 translate E TwinsDeleteOlder {Smaller game number}
 translate E TwinsDeleteNewer {Larger game number}
@@ -1294,14 +1304,14 @@ translate E CommonSorts {Common sorts}
 translate E Sort {Sort}
 
 # Exporting:
-translate E AddToExistingFile {Add games to an existing file?}
-translate E ExportComments {Export comments?}
-translate E ExportVariations {Export variations?}
-translate E IndentComments {Indent comments?}
-translate E IndentVariations {Indent variations?}
-translate E ExportColumnStyle {Column style (one move per line)?}
+translate E AddToExistingFile {Add games to an existing file}
+translate E ExportComments {Export comments}
+translate E ExportVariations {Export variations}
+translate E IndentComments {Indent comments}
+translate E IndentVariations {Indent variations}
+translate E ExportColumnStyle {Column style (one move per line)}
 translate E ExportSymbolStyle {Symbolic annotation style:}
-translate E ExportStripMarks {Strip square/arrow mark codes from comments?}
+translate E ExportStripMarks {Strip square/arrow mark\ncodes from comments}
 
 # Goto game/move dialogs:
 translate E LoadGameNumber {Enter the game number to load:}
@@ -1337,9 +1347,7 @@ translate E FindNovelty {Find Novelty}
 translate E Novelty {Novelty}
 translate E NoveltyInterrupt {Novelty search interrupted}
 translate E NoveltyNone {No novelty was found for this game}
-translate E NoveltyHelp {
-Scid will find the first move of the current game that reaches a position not found in the selected database or in the ECO openings book.
-}
+translate E NoveltyHelp {Scid will find the first move of the current game that reaches a position not found in the selected database or in the ECO openings book.}
 
 # Sounds configuration:
 translate E SoundsFolder {Sound Files Folder}
@@ -1482,7 +1490,7 @@ translate E TimeSec {sec}
 translate E AllExercisesDone {All exercises done}
 translate E MoveOutOfBook {Move out of book}
 translate E LastBookMove {Last book move}
-translate E AnnotateSeveralGames {Annotate several games\nfrom current to :}
+translate E AnnotateSeveralGames {From actual game to game:}
 translate E FindOpeningErrors {Find opening errors}
 translate E MarkTacticalExercises {Mark tactical exercises}
 translate E UseBook {Use book}
@@ -1618,7 +1626,7 @@ translate E CCDlgDefaultDB {Default Database:}
 translate E CCDlgInbox {Inbox (path):}
 translate E CCDlgOutbox {Outbox (path):}
 translate E CCDlgXfcc {Xfcc Configuration:}
-translate E CCDlgExternalProtocol {External Protocol Handler (e.g. Xfcc)}
+translate E CCDlgExternalProtocol {External Protocol\nHandler (e.g. Xfcc)}
 translate E CCDlgFetchTool {Fetch Tool:}
 translate E CCDlgSendTool {Send Tool:}
 translate E CCDlgEmailCommunication {eMail Communication}
@@ -1629,10 +1637,10 @@ translate E CCDlgThunderbirdEg {e.g. Thunderbird, Mozilla Mail, Icedove...}
 translate E CCDlgMailUrlEg {e.g. Evolution}
 translate E CCDlgClawsEg {e.g Sylpheed Claws}
 translate E CCDlgmailxEg {e.g. mailx, mutt, nail...}
-translate E CCDlgAttachementPar {Attachment parameter:}
+translate E CCDlgAttachementPar {Attachment\nparameter:}
 translate E CCDlgInternalXfcc {Use internal Xfcc support}
 translate E CCDlgConfirmXfcc {Confirm moves}
-translate E CCDlgSubjectPar {Subject parameter:}
+translate E CCDlgSubjectPar {Subject\nparameter:}
 translate E CCDlgDeleteBoxes {Empty In-/Outbox}
 translate E CCDlgDeleteBoxesText {Do you really want to empty your In- and Outbox folders for Correspondence Chess?\nThis requires a new sync to show the last state of your games.}
 translate E CCDlgConfirmMove {Confirm move}
@@ -1723,7 +1731,43 @@ translate E DockRight {Move to right}
 translate E Undock {Undock}
 
 # Switcher window
-translate E ChangeIcon {Change icon...}
+translate E ChangeIcon {Choose database icon...}
+translate E NewGameListWindow {New Game List Window}
+translate E LoadatStartup {Load at startup}
 
+# Gamelist window
+translate E ShowHideDB {Show/Hide databases}
+translate E ChangeFilter {Change filter}
+translate E ChangeLayout {Load/Save/Change sorting criteria and column layout}
+translate E ShowHideStatistic {Show/Hide statistics}
+translate E BoardFilter {Show only games that matches the current board position}
+translate E CopyGameTo {Copy Game to}
+translate E FindBar {Find Bar}
+translate E FindCurrentGame {Find current game}
+translate E DeleteGame {Delete game}
+translate E UndeleteGame {Undelete game}
+translate E ResetSort {Reset sort}
+
+translate E ConvertNullMove {Convert null moves to comments}
+translate E SetupBoard {Setup Board}
+translate E Rotate {Rotate}
+translate E SwitchColors {Switch colors}
+translate E FlipBoard {Flip Board}
+translate E ImportPGN {Import PGN game}
+translate E ImportingFiles {Importing PGN files in}
+translate E ImportingFrom {Importing from}
+translate E ImportingIn {Import games in}
+translate E UseLastTag {Use last\ngame's tags}
+translate E Random {Random}
+translate E BackToMainline {Go back to mainline}
+translate E LeaveVariant {Leave variant}
+translate E Autoplay {Autoplay}
+translate E ShowHideCoords {Show/Hide Coord.}
+translate E ShowHideMaterial {Show/Hide Material}
+translate E FullScreen {Full Screen}
+translate E FilterStatistic {Filter Statistics}
+translate E MakeCorrections {Make Corrections}
+translate E Surnames {Surnames}
+translate E Ambiguous {Ambiguous}
 }
 # end of english.tcl
