@@ -1,5 +1,3 @@
-#!/bin/sh
-
 # Scid (Shane's Chess Information Database)
 #
 # Copyright (C) 1999-2004 Shane Hudson
@@ -16,44 +14,24 @@
 # Set default values
 
 proc InitDefaultToolbar {} {
-  global toolbar
   foreach {tbicon status}  {
-    new 0 open 0 save 0 close 0
+    newdb 0 open 0 save 0 closedb 0
     finder 0 bkm 0 gprev 0 gnext 0
-    cut 0 copy 0 paste 0
-    rfilter 0 bsearch 0 hsearch 0 msearch 0
-    switcher 0 glist 0 pgn 0 tmt 0 maint 0 eco 0 tree 0 crosst 0 engine 0
+    newgame 0 copy 0 paste 0
+    boardsearch 0 headersearch 0 materialsearch 0
+    switcher 0 glist 0 pgn 0 tmt 0 maint 0 eco 0 tree 0 crosstab 0 engine 0
   } {
-    set toolbar($tbicon) $status
+    set ::toolbar_state($tbicon) $status
   }
 }
 
 proc InitWinsDefaultGeometry {} {
-  global winX winY winWidth winHeight
-
-  # Default window locations:
-  foreach i {. .pgnWin .helpWin .crosstabWin .treeWin .commentWin .glist
-    .playerInfoWin .baseWin .treeBest .treeGraph .tourney .finder
-    .ecograph .statsWin .glistWin .maintWin .nedit} {
-    set winX($i) -1
-    set winY($i) -1
-  }
-
-  for {set b [sc_info limit bases] } {$b > 0} {incr b -1} {
-    foreach i { .treeWin .treeBest .treeGraph } {
-        set winX($i$b) -1
-        set winY($i$b) -1
-    }
-  }
+  global winWidth winHeight
 
   # Default window size:
   set winWidth(.) 1024
   set winHeight(.) 570
 
-  # Default PGN window size:
-  set winWidth(.pgnWin)  65
-  set winHeight(.pgnWin) 20
-
   # Default help window size:
   set winWidth(.helpWin)  50
   set winHeight(.helpWin) 32
@@ -62,49 +40,19 @@ proc InitWinsDefaultGeometry {} {
   set winWidth(.statsWin) 60
   set winHeight(.statsWin) 13
 
-  # Default crosstable window size:
-  set winWidth(.crosstabWin)  65
-  set winHeight(.crosstabWin) 15
-
-  # Default tree window size:
-  set winWidth(.treeWin)  58
-  set winHeight(.treeWin) 20
-
-  # Default comment editor size:
-  set winWidth(.commentWin)  40
-  set winHeight(.commentWin)  6
-
   # Default spellcheck results window size:
   set winWidth(.spellcheckWin)  55
   set winHeight(.spellcheckWin) 25
 
-  # Default player info window size:
-  set winWidth(.playerInfoWin)  45
-  set winHeight(.playerInfoWin) 20
-
-  # Default switcher window size:
-  set winWidth(.baseWin) 310
-  set winHeight(.baseWin) 110
-
   # Default Correspondence Chess window size:
   set winWidth(.ccWindow) 10
   set winHeight(.ccWindow) 20
 
-  # Default fics window size
-  set winWidth(.fics) 500
-  set winHeight(.fics) 600
-
-  # Default size for input engine console:
-  ###---### needs adjustment!
-  set winWidth(.inputengineconsole) 10
-  set winHeight(.inputengineconsole) 20
-
   # List of saved layouts : 3 slots available
   set ::docking::layout_list(1) {}
-  set ::docking::layout_list(2) {{.pw vertical} {TPanedwindow {{.pw.pw0 horizontal} {TNotebook .nb .fdockmain} {TNotebook .tb1 .fdockpgnWin}}}}
-  set ::docking::layout_list(3) {{MainWindowGeometry 1024x542+0+0 zoomed} {{.pw vertical {}} {TPanedwindow {{.pw.pw0 horizontal {}} {TPanedwindow {{.pw.pw0.pw2 vertical 360} {TPanedwindow {{.pw.pw0.pw2.pw6 horizontal 368} {TNotebook .nb .fdockmain} {TPanedwindow {{.pw.pw0.pw2.pw6.pw8 vertical 196} {TNotebook .tb7 .fdockpgnWin} {TNotebook .tb9 .fdockanalysisWin1}}}}} {TPanedwindow {{.pw.pw0.pw2.pw4 horizontal {}} {TNotebook .tb3 .fdockglistWin1}}}}}}}}}
-  set ::docking::layout_list(auto) {{MainWindowGeometry 1024x532+0+0} {{.pw vertical {}} {TPanedwindow {{.pw.pw0 horizontal {}} {TPanedwindow {{.pw.pw0.pw2 vertical {}} {TPanedwindow {{.pw.pw0.pw2.pw6 horizontal 413} {TNotebook .nb .fdockmain} {TPanedwindow {{.pw.pw0.pw2.pw6.pw8 vertical 270} {TNotebook .tb7 {.fdockanalysisWin1 .fdockpgnWin}} {TNotebook .tb9 .fdockglistWin1}}}}}}}}}}}
-
+  set ::docking::layout_list(2) {{MainWindowGeometry 540x650+0+0} {{.pw vertical {}} {TNotebook .nb .fdockmain}}}
+  set ::docking::layout_list(3) {{MainWindowGeometry 1024x532+0+0} {{.pw vertical {}} {TPanedwindow {{.pw.pw0 horizontal 413} {TNotebook .nb .fdockmain} {TPanedwindow {{.pw.pw0.pw1 vertical 270} {TNotebook .tb2 {.fdockanalysisWin1 .fdockpgnWin}} {TNotebook .tb3 .fdockglistWin1}}}}}}}
+  set ::docking::layout_list(auto) {{MainWindowGeometry 1024x532+0+0} {{.pw vertical {}} {TPanedwindow {{.pw.pw0 horizontal 413} {TNotebook .nb .fdockmain} {TPanedwindow {{.pw.pw0.pw1 vertical 270} {TNotebook .tb2 {.fdockanalysisWin1 .fdockpgnWin}} {TNotebook .tb3 .fdockglistWin1}}}}}}}
 }
 
 proc InitDefaultStats {} {
@@ -163,11 +111,30 @@ proc InitDefaultFonts {} {
   }
 }
 
+proc InitDefaultGListLayouts {} {
+  set ::glist_Layouts {RatingDate DateEvent Full}
+  set ::glist_ColOrder(RatingDate) {{7} {1} {2} {3} {4} {5} {6} {23} {22} {8} {9} {10} {11} {12} {13} {14} {15} {16} {0}}
+  set ::glist_ColWidth(RatingDate) {{50} {50} {50} {120} {40} {120} {40} {80} {200} {30}  {200} {30} {20} {20} {20} {20} {35} {50} {30} {100} {40} {40} {50} {140}}
+  set ::glist_ColAnchor(RatingDate) {{e} {c} {c} {w} {c} {w} {c} {w} {w} {e}  {w} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {w}}
+  set ::glist_Sort(RatingDate) { {22} {-} {7} {-} }
+  set ::glist_FindBar(RatingDate) 0
+  set ::glist_ColOrder(DateEvent) {7 3 4 5 6 1 23 8 9 10 0}
+  set ::glist_ColWidth(DateEvent) {50 50 50 120 40 120 40 80 145 30 112 30 20 20 20 20 35 50 30 100 40 40 50 153}
+  set ::glist_ColAnchor(DateEvent) {{e} {c} {c} {w} {c} {w} {c} {w} {w} {e}  {w} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {w}}
+  set ::glist_Sort(DateEvent) {7 - 8 - 9 -}
+  set ::glist_FindBar(DateEvent) 0
+  set ::glist_ColOrder(Full) {20 7 3 4 5 6 1 2 23 8 19 10 9 16 17 22 21 18 11 12 13 14 15 0}
+  set ::glist_ColWidth(Full) {50 50 39 120 40 120 40 70 200 30 200 30 20 20 20 20 35 119 30 78 40 40 50 155}
+  set ::glist_ColAnchor(Full) {{e} {c} {c} {w} {c} {w} {c} {w} {w} {e}  {w} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {w}}
+  set ::glist_Sort(Full) {0 +}
+  set ::glist_FindBar(Full) 0
+}
+
 InitDefaultFonts
 InitWinsDefaultGeometry
 InitDefaultToolbar
 InitDefaultStats
-
+InitDefaultGListLayouts
 
 #Default textures for lite and dark squares
 set boardfile_dark "LightWood3-d"
@@ -197,6 +164,10 @@ set bestcolor   "\#bebebe"
 set buttoncolor "\#b0c0d0"
 set borderwidth 0
 
+# Square markers color and type
+set ::markColor green
+set ::markType full
+
 # boardCoords: 1 to show board Coordinates, 0 to hide them.
 set boardCoords 0
 
@@ -213,6 +184,7 @@ set language E
 
 # Default theme
 set ::lookTheme "default"
+set ::ThemePackageFile ""
 
 # Auto-save options when exiting:
 set optionsAutoSave 1
@@ -283,21 +255,6 @@ if {$windowsOS} {
   set analysisChoices {crafty}
 }
 
-set comp(timecontrol) pergame
-set comp(seconds) 180
-set comp(minutes) 1
-set comp(incr) 0
-set comp(timeout) 0 ;# disabled by default
-set comp(name) "Engine tournament"
-set comp(rounds) 2
-set comp(showclock) 0
-set comp(debug) 1 ; # print info to console
-set comp(animate) 1
-set comp(firstonly) 0
-set comp(ponder) 0
-set comp(usebook) 0
-set comp(book) {}
-
 # Default Tree sort method:
 set tree(order) frequency
 
@@ -354,8 +311,6 @@ set ::fics::server_ip "0.0.0.0"
 set ::fics::premoveEnabled 1
 set ::fics::playing 0
 
-set ::commenteditor::showboard 1
-
 # default resolvers for player info
 set ::pinfo::wikipAPI      "http://de.wikipedia.org/w/api.php?action=query&format=xml"
 # Appers PND resolver
@@ -418,15 +373,9 @@ array set geometry {}
 
 # startup:
 #   Stores which windows should be opened on startup.
-set startup(pgn) 0
-set startup(switcher) 0
 set startup(tip) 1
-set startup(tree) 0
 set startup(finder) 0
-set startup(crosstable) 0
-set startup(gamelist) 0
 set startup(stats) 0
-set startup(book) 0
 
 
 # Game information area options:
@@ -521,13 +470,13 @@ set informant("++-") 5.5
 set exportFlags(comments) 1
 set exportFlags(indentc) 0
 set exportFlags(vars) 1
-set exportFlags(indentv) 1
+set exportFlags(indentv) 0
 set exportFlags(column) 0
 set exportFlags(append) 0
-set exportFlags(symbols) 1
+set exportFlags(symbols) 0
 set exportFlags(htmldiag) 0
 set exportFlags(stripMarks) 0
-set exportFlags(convertNullMoves) 1
+set exportFlags(convertNullMoves) 0
 set default_exportStartFile(PGN) {}
 set default_exportEndFile(PGN) {}
 
@@ -554,8 +503,16 @@ set default_exportEndFile(LaTeX) {\end{document}
 
 
 set default_exportStartFile(HTML) {<html>
-  <head><title>Scid export</title></head>
+  <head>
+    <title>Scid export</title>
+    <style>
+      @media print {
+        table { page-break-inside: avoid; }
+      }
+    </style>
+  </head>
   <body bgcolor="#ffffff">
+
 }
 set default_exportEndFile(HTML) {</body>
   </html>
@@ -603,17 +560,13 @@ if {[file readable $email(oldlogfile)]  &&  ![file readable $email(logfile)]} {
 }
 
 ### Audio move announcement options:
-set ::utils::sound::soundFolder [file nativename [file join $::scidExeDir sounds]]
+set ::utils::sound::soundFolder [file nativename [file join $::scidShareDir sounds]]
 set ::utils::sound::announceNew 0
 set ::utils::sound::announceForward 0
 set ::utils::sound::announceBack 0
 
 # Spell-checking file: default is "spelling.ssp".
-if {$windowsOS} {
-  set spellCheckFile [file join $scidExeDir "spelling.ssp"]
-} else {
-  set spellCheckFile "/usr/local/share/scid/spelling.ssp"
-}
+set spellCheckFile [file join $scidShareDir "spelling.ssp"]
 
 # book configuration
 set ::book::lastBook "" ; # book name without extension (.bin)
@@ -665,7 +618,9 @@ set optionsFile [scidConfigFile options]
 ################################################################################
 #  Load options file. All default values should be set before this point or new saved values will be overwritten by default ones
 ################################################################################
-catch {source $optionsFile}
+if {[file exists $optionsFile] && [catch {source $optionsFile}]} {
+  tk_messageBox -message $::errorInfo
+}
 
 # Now, if the options file was written by Scid 3.5 or older, it has a lot of
 # yucky variable names in the global namespace. So convert them to the new
@@ -737,13 +692,18 @@ proc options.write {} {
           ::sergame::startFromCurrent ::sergame::coachIsWatching ::sergame::timeMode \
           ::sergame::depth ::sergame::movetime ::sergame::nodes ::sergame::ponder ::sergame::isOpening \
           ::uci::uciInfo(wtime3) ::uci::uciInfo(winc3) ::uci::uciInfo(btime3) ::uci::uciInfo(binc3) \
-			 ::commenteditor::showboard \
           boardfile_lite boardfile_dark \
           FilterMaxMoves FilterMinMoves FilterStepMoves FilterMaxElo FilterMinElo FilterStepElo \
-          FilterMaxYear FilterMinYear FilterStepYear FilterGuessELO lookTheme autoResizeBoard } {
+          FilterMaxYear FilterMinYear FilterStepYear FilterGuessELO lookTheme ThemePackageFile autoResizeBoard } {
       puts $optionF "set $i [list [set $i]]"
     }
     
+    foreach i [lsort [array names menuColor]] {
+      puts $optionF "set menuColor($i) [list $menuColor($i)]"
+    }
+    foreach i [lsort [array names menuBarColor]] {
+      puts $optionF "set menuBarColor($i) [list $menuBarColor($i)]"
+    }
     puts $optionF ""
     foreach i [lsort [array names winWidth]] {
       puts $optionF "set winWidth($i)  [expr $winWidth($i)]"
@@ -775,8 +735,8 @@ proc options.write {} {
     foreach i [lsort [array names startup]] {
       puts $optionF "set startup($i) [list $startup($i)]"
     }
-    foreach i [lsort [array names toolbar]] {
-      puts $optionF "set toolbar($i) [list $toolbar($i)]"
+    foreach i [lsort [array names toolbar_state]] {
+      puts $optionF "set toolbar_state($i) [list $toolbar_state($i)]"
     }
     foreach i [lsort [array names twinSettings]] {
       puts $optionF "set twinSettings($i) [list $twinSettings($i)]"
@@ -786,7 +746,7 @@ proc options.write {} {
       puts $optionF "set fontOptions($i) [list $fontOptions($i)]"
     }
     puts $optionF ""
-    foreach type {base book html tex stm pgn report tablebase1 tablebase2 tablebase3 tablebase4} {
+    foreach type [array names initialDir] {
       puts $optionF "set initialDir($type) [list $initialDir($type)]"
     }
     puts $optionF ""
@@ -824,6 +784,15 @@ proc options.write {} {
     foreach slot {1 2 3 auto} {
       puts $optionF "set ::docking::layout_list($slot) [list $::docking::layout_list($slot)]"
     }
+    foreach wnd [array names ::winGeometry] {
+      if {[winfo exists $wnd]} {
+        ::win::saveWinGeometry $wnd
+      }
+      if {$::winGeometry($wnd) ne ""} {
+        puts $optionF "set ::winGeometry($wnd) $::winGeometry($wnd)"
+      }
+    }
+
     
     # Save var that was added with options.save()
     if {[info exists ::autosave_opt]} {
