@@ -26,29 +26,32 @@ set sPgntext(3) ""
 #    Checks minimum/maximum search dates in header search window and
 #    extends them if necessary.
 proc checkDates {} {
-  global sDateMin sDateMax
-  if {[string length $sDateMin] == 0} { set sDateMin "0000" }
-  if {[string length $sDateMax] == 0} { set sDateMax [sc_info limit year]}
+  global sDateMin sDateMax sEventDateMin sEventDateMax
   if {[string length $sDateMin] == 4} { append sDateMin ".??.??" }
   if {[string length $sDateMax] == 4} { append sDateMax ".12.31" }
   if {[string length $sDateMin] == 7} { append sDateMin ".??" }
   if {[string length $sDateMax] == 7} { append sDateMax ".31" }
+  if {[string length $sEventDateMin] == 4} { append sDateMin ".??.??" }
+  if {[string length $sEventDateMax] == 4} { append sDateMax ".12.31" }
+  if {[string length $sEventDateMin] == 7} { append sDateMin ".??" }
+  if {[string length $sEventDateMax] == 7} { append sDateMax ".31" }
 }
 
 proc ::search::header::defaults {} {
   set ::sWhite "";  set ::sBlack ""
   set ::sEvent ""; set ::sSite "";  set ::sRound ""; set ::sAnnotator ""; set ::sAnnotated 0
-  set ::sWhiteEloMin 0; set ::sWhiteEloMax [sc_info limit elo]
-  set ::sBlackEloMin 0; set ::sBlackEloMax [sc_info limit elo]
-  set ::sEloDiffMin "-[sc_info limit elo]"
-  set ::sEloDiffMax "+[sc_info limit elo]"
-  set ::sGlMin 0; set ::sGlMax 999
-  set ::sEcoMin "A00";  set ::sEcoMax "E99"; set ::sEco Yes
-  set ::sGnumMin 1; set ::sGnumMax -1
-  set ::sDateMin "0000.00.00"; set ::sDateMax "[sc_info limit year].12.31"
+  set ::sWhiteEloMin ""; set ::sWhiteEloMax ""
+  set ::sBlackEloMin ""; set ::sBlackEloMax ""
+  set ::sEloDiffMin ""; set ::sEloDiffMax ""
+  set ::sGlMin ""; set ::sGlMax ""
+  set ::sEcoMin "";  set ::sEcoMax ""; set ::sEco Yes
+  set ::sGnumMin ""; set ::sGnumMax ""
+  set ::sDateMin ""; set ::sDateMax ""
+  set ::sEventDateMin ""; set ::sEventDateMax ""
   set ::sResWin ""; set ::sResLoss ""; set ::sResDraw ""; set ::sResOther ""
   set ::sIgnoreCol No
-  set ::sSideToMove wb
+  set ::sSideToMoveW "w"
+  set ::sSideToMoveB "b"
   foreach flag  [ concat $::sHeaderFlagList $::sHeaderCustomFlagList ] { set ::sHeaderFlags($flag) both }
   foreach i [array names ::sPgntext] { set ::sPgntext($i) "" }
   foreach i $::sTitleList {
@@ -57,17 +60,20 @@ proc ::search::header::defaults {} {
   }
 }
 
-::search::header::defaults
-
-trace variable sDateMin w ::utils::validate::Date
-trace variable sDateMax w ::utils::validate::Date
-
 foreach i {sWhiteEloMin sWhiteEloMax sBlackEloMin sBlackEloMax} {
   trace variable $i w [list ::utils::validate::Integer [sc_info limit elo] 0]
 }
 trace variable sEloDiffMin w [list ::utils::validate::Integer "-[sc_info limit elo]" 0]
 trace variable sEloDiffMax w [list ::utils::validate::Integer "-[sc_info limit elo]" 0]
 
+::search::header::defaults
+
+trace variable sDateMin w ::utils::validate::Date
+trace variable sDateMax w ::utils::validate::Date
+trace variable sEventDateMin w ::utils::validate::Date
+trace variable sEventDateMax w ::utils::validate::Date
+
+
 trace variable sGlMin w {::utils::validate::Integer 9999 0}
 trace variable sGlMax w {::utils::validate::Integer 9999 0}
 
@@ -85,115 +91,131 @@ set sHeaderFlagFrame 0
 #
 #   Opens the window for searching by header information.
 #
-proc search::header {{ref_base ""} {ref_filter ""}} {
-  global sWhite sBlack sEvent sSite sRound sAnnotator sAnnotated sDateMin sDateMax sIgnoreCol
+proc ::search::header {{ref_base ""} {ref_filter "dbfilter"}} {
+  ::search::Open $ref_base $ref_filter HeaderSearch ::search::headerCreateFrame
+}
+
+proc search::headerCreateFrame { w } {
+  global sWhite sBlack sEvent sSite sRound sAnnotator sAnnotated sEventDateMin sEventDateMax sIgnoreCol
   global sWhiteEloMin sWhiteEloMax sBlackEloMin sBlackEloMax
-  global sEloDiffMin sEloDiffMax sSideToMove
+  global sEloDiffMin sEloDiffMax sSideToMoveW sSideToMoveB
   global sEco sEcoMin sEcoMax sHeaderFlags sGlMin sGlMax sTitleList sTitles
   global sResWin sResLoss sResDraw sResOther sPgntext
 
-  set w .sh
-  if {[winfo exists $w]} {
-    wm deiconify $w
-    raiseWin $w
-    return
-  }
-  
-  toplevel $w
-  wm title $w "Scid: $::tr(HeaderSearch)"
-  foreach frame {cWhite cBlack ignore tw tb eventsite dateround res ano gl ends eco} {
+  foreach frame {cWhite cBlack ignore tw tb eventsite eventround date res ano gl ends eco} {
     ttk::frame $w.$frame
   }
   
-  raise $w
-  
-  bind $w <F1> { helpWindow Searches Header }
-  bind $w <Escape> "$w.b.cancel invoke"
-  bind $w <Return> "$w.b.search invoke"
-  
-  if {$ref_base != ""} {
-    set ::refDatabaseH $ref_base
-    set ::refFilterH $ref_filter
-  } else {
-    pack [ttk::frame $w.refdb] -side top -fill x
-    CreateSelectDBWidget "$w.refdb" "refDatabaseH" "$ref_base"
-    addHorizontalRule $w
-    set ::refFilterH ""
-  }
-
   set regular font_Small
-  set bold font_SmallBold
-  
+  ttk::labelframe $w.player -text $::tr(Player)
+  pack $w.player -side top -fill x -pady 5
   foreach color {White Black} {
-    pack $w.c$color -side top -fill x
-    ttk::label $w.c$color.lab -textvar ::tr($color:) -font $bold -width 9 -anchor w
+    pack $w.c$color -side top -fill x -in $w.player
+    ttk::label $w.c$color.lab -textvar ::tr($color:) -width 9 -anchor w
     ttk::combobox $w.c$color.e -textvariable "s$color" -width 40
     ::utils::history::SetCombobox HeaderSearch$color $w.c$color.e
-    bind $w.c$color.e <Return> { .sh.b.search invoke; break }
     
     ttk::label $w.c$color.space
-    ttk::label $w.c$color.elo1 -textvar ::tr(Rating:) -font $bold
-    ttk::entry $w.c$color.elomin -textvar s${color}EloMin -width 6 -justify right \
-        -font $regular
-    ttk::label $w.c$color.elo2 -text "-" -font $regular
-    ttk::entry $w.c$color.elomax -textvar s${color}EloMax -width 6 -justify right \
-        -font $regular
+    ttk::label $w.c$color.elo1 -textvar ::tr(Rating:)
+    ttk::entry $w.c$color.elomin -textvar s${color}EloMin -width 6 -justify right
+    ttk::label $w.c$color.elo2 -text "-"
+    ttk::entry $w.c$color.elomax -textvar s${color}EloMax -width 6 -justify right
     bindFocusColors $w.c$color.e
     bindFocusColors $w.c$color.elomin
     bindFocusColors $w.c$color.elomax
     pack $w.c$color.lab $w.c$color.e $w.c$color.space -side left
-    pack $w.c$color.elomax $w.c$color.elo2 $w.c$color.elomin $w.c$color.elo1 \
-        -side right
+    pack $w.c$color.elomax $w.c$color.elo2 $w.c$color.elomin $w.c$color.elo1 -side right
   }
-  
-  pack $w.ignore -side top -fill x
-  ttk::label $w.ignore.l -textvar ::tr(IgnoreColors:) -font $bold
-  ttk::radiobutton $w.ignore.yes -variable sIgnoreCol -value Yes -textvar ::tr(Yes) -style Small.TRadiobutton
-  ttk::radiobutton $w.ignore.no  -variable sIgnoreCol -value No -textvar ::tr(No) -style Small.TRadiobutton
-  pack $w.ignore.l $w.ignore.yes $w.ignore.no -side left
-  ttk::label $w.ignore.rdiff -textvar ::tr(RatingDiff:) -font $bold
-  ttk::entry $w.ignore.rdmin -width 6 -textvar sEloDiffMin -justify right -font $regular
-  ttk::label $w.ignore.rdto -text "-" -font $regular
-  ttk::entry $w.ignore.rdmax -width 6 -textvar sEloDiffMax -justify right -font $regular
+
+  pack $w.ignore -side top -fill x -in $w.player
+  ttk::checkbutton $w.ignore.yes -variable sIgnoreCol -onvalue Yes -offvalue No -textvar ::tr(IgnoreColors)
+  pack $w.ignore.yes -side left
+  ttk::label $w.ignore.rdiff -textvar ::tr(RatingDiff:)
+  ttk::entry $w.ignore.rdmin -width 6 -textvar sEloDiffMin -justify right
+  ttk::label $w.ignore.rdto -text "-"
+  ttk::entry $w.ignore.rdmax -width 6 -textvar sEloDiffMax -justify right
   bindFocusColors $w.ignore.rdmin
   bindFocusColors $w.ignore.rdmax
-  pack $w.ignore.rdmax $w.ignore.rdto $w.ignore.rdmin $w.ignore.rdiff \
-      -side right
-  
+  pack $w.ignore.rdmax $w.ignore.rdto $w.ignore.rdmin $w.ignore.rdiff -side right
+
+  pack [ttk::separator $w.sep] -side top -fill x -in $w.player
   set spellstate normal
   if {[lindex [sc_name read] 0] == 0} { set spellstate disabled }
   foreach c {w b} name {White Black} {
-    pack $w.t$c -side top -fill x
-    ttk::label $w.t$c.label -text "$::tr($name) FIDE:" -font $bold -width 14 -anchor w
+    pack $w.t$c -side top -fill x -in $w.player
+    ttk::label $w.t$c.label -text "$::tr($name) FIDE:" -width 14 -anchor w
     pack $w.t$c.label -side left
     foreach i $sTitleList {
       set name [string toupper $i]
       if {$i == "none"} { set name "-" }
-      ttk::checkbutton $w.t$c.b$i -text $name -width 5 -variable sTitles($c:$i) -offvalue 0 -onvalue 1 -state $spellstate
-      pack $w.t$c.b$i -side left -padx 1
+      ttk::checkbutton $w.t$c.b$i -text $name -variable sTitles($c:$i) -offvalue 0 -onvalue 1 -state $spellstate
+      pack $w.t$c.b$i -side left -padx "0 10"
     }
   }
   
-  addHorizontalRule $w
+  lower $w.player
   
+  ttk::labelframe $w.tournement -text $::tr(Event)
+  pack $w.tournement -side top -fill x -pady 5
   set f $w.eventsite
-  pack $f -side top -fill x
+  pack $f -side top -fill x -in $w.tournement -pady "0 3"
   foreach i {Event Site} {
-    ttk::label $f.l$i -textvar ::tr(${i}:) -font $bold
+    ttk::label $f.l$i -textvar ::tr(${i}:)
     ttk::combobox $f.e$i -textvariable s$i -width 30
-    bind $f.e$i <Return> { .sh.b.search invoke ; break }
     ::utils::history::SetCombobox HeaderSearch$i $f.e$i
     bindFocusColors $f.e$i
   }
   pack $f.lEvent $f.eEvent -side left
-  pack $f.eSite $f.lSite -side right
+  pack $f.eSite -side right
+  pack $f.lSite -side right -padx "10 0"
   
-  set f $w.dateround
-  pack $f -side top -fill x
-  ttk::label $f.l1 -textvar ::tr(Date:) -font $bold
-  ttk::label $f.l2 -text "-" -font $regular
-  ttk::label $f.l3 -text " " -font $regular
-  ttk::entry $f.emin -textvariable sDateMin -width 10 -font $regular
+  set f $w.eventround
+  pack $f -side top -fill x -in $w.tournement
+  lower $w.tournement
+  ## Setup date of Event
+  ttk::label $f.dl1 -text "$::tr(Event)\n$::tr(Date:)"
+  ttk::label $f.dl2 -text "-"
+  ttk::label $f.dl3 -text " "
+  ttk::entry $f.demin -textvariable sEventDateMin -width 10
+  button $f.deminCal -image tb_calendar -padx 0 -pady 0 -command {
+    regsub -all {[.]} $sEventDateMin "-" newdate
+    set ndate [::utils::date::chooser $newdate]
+    if {[llength $ndate] == 3} {
+      set sEventDateMin "[lindex $ndate 0].[lindex $ndate 1].[lindex $ndate 2]"
+    }
+  }
+  ttk::entry $f.demax -textvariable sEventDateMax -width 10
+  button $f.demaxCal -image tb_calendar -padx 0 -pady 0 -command {
+    regsub -all {[.]} $sEventDateMax "-" newdate
+    set ndate [::utils::date::chooser $newdate]
+    if {[llength $ndate] == 3} {
+      set sEventDateMax "[lindex $ndate 0].[lindex $ndate 1].[lindex $ndate 2]"
+    }
+  }
+  bindFocusColors $f.demin
+  bindFocusColors $f.demax
+  bind $f.demin <FocusOut> +checkDates
+  bind $f.demax <FocusOut> +checkDates
+  ttk::button $f.dlyear -textvar ::tr(YearToToday) -style Pad0.Small.TButton -command {
+    set sEventDateMin "[expr [::utils::date::today year]-1].[::utils::date::today month].[::utils::date::today day]"
+    set sEventDateMax [::utils::date::today]
+  }
+  ::utils::tooltip::Set $f.dlyear $::tr(YearToTodayTooltip)
+
+  pack $f.dl1 $f.demin $f.deminCal $f.dl2 $f.demax $f.demaxCal $f.dl3 $f.dlyear -side left
+
+  ttk::label $f.lRound -textvar ::tr(Round:)
+  ttk::entry $f.eRound -textvariable sRound -width 10
+  bindFocusColors $f.eRound
+  pack $f.eRound $f.lRound -side right
+
+  set f $w.date
+  pack $f -side top -fill x -in $w.tournement -pady "0 3"
+  ## Setup Date of Game
+  ttk::label $f.l1 -text "$::tr(game)\n$::tr(Date:)"
+  ttk::label $f.l2 -text "-"
+  ttk::label $f.l3 -text " "
+  ttk::entry $f.emin -textvariable sDateMin -width 10
   button $f.eminCal -image tb_calendar -padx 0 -pady 0 -command {
     regsub -all {[.]} $sDateMin "-" newdate
     set ndate [::utils::date::chooser $newdate]
@@ -201,7 +223,7 @@ proc search::header {{ref_base ""} {ref_filter ""}} {
       set sDateMin "[lindex $ndate 0].[lindex $ndate 1].[lindex $ndate 2]"
     }
   }
-  ttk::entry $f.emax -textvariable sDateMax -width 10 -font $regular
+  ttk::entry $f.emax -textvariable sDateMax -width 10
   button $f.emaxCal -image tb_calendar -padx 0 -pady 0 -command {
     regsub -all {[.]} $sDateMax "-" newdate
     set ndate [::utils::date::chooser $newdate]
@@ -217,62 +239,52 @@ proc search::header {{ref_base ""} {ref_filter ""}} {
     set sDateMin "[expr [::utils::date::today year]-1].[::utils::date::today month].[::utils::date::today day]"
     set sDateMax [::utils::date::today]
   }
-  
+  ::utils::tooltip::Set $f.lyear $::tr(YearToTodayTooltip)
+
   pack $f.l1 $f.emin $f.eminCal $f.l2 $f.emax $f.emaxCal $f.l3 $f.lyear -side left
   
-  ttk::label $f.lRound -textvar ::tr(Round:) -font $bold
-  ttk::entry $f.eRound -textvariable sRound -width 10 -font $regular
-  bindFocusColors $f.eRound
-  pack $f.eRound $f.lRound -side right
-  
-  addHorizontalRule $w
-  
-  pack .sh.res -side top -fill x
-  ttk::label $w.res.l1 -textvar ::tr(Result:) -font $bold
-  pack $w.res.l1 -side left
+  ttk::labelframe $w.result -text $::tr(Result)
+  pack $w.result -side top -fill x -pady 5
+  pack $w.res -side top -fill x -in $w.result
+  ttk::label $w.res.l1 -textvar ::tr(Result:)
   ttk::checkbutton $w.res.ewin -text "1-0 " -variable sResWin -offvalue "1" -onvalue ""
   ttk::checkbutton $w.res.edraw -text "1/2-1/2 " -variable sResDraw -offvalue "=" -onvalue ""
   ttk::checkbutton $w.res.eloss -text "0-1 " -variable sResLoss -offvalue "0" -onvalue ""
   ttk::checkbutton $w.res.eother -text "* " -variable sResOther -offvalue "*" -onvalue ""
-  pack $w.res.ewin $w.res.edraw $w.res.eloss $w.res.eother -side left
-  
-  ttk::label $w.gl.l1 -textvar ::tr(GameLength:) -font $bold
-  ttk::label $w.gl.l2 -text "-" -font $regular
-  ttk::label $w.gl.l3 -textvar ::tr(HalfMoves) -font $regular
-  ttk::entry $w.gl.emin -textvariable sGlMin -justify right -width 4 -font $regular
-  ttk::entry $w.gl.emax -textvariable sGlMax -justify right -width 4 -font $regular
+  pack $w.res.l1 $w.res.ewin $w.res.edraw $w.res.eloss $w.res.eother -side left
+  lower $w.result
+
+  ttk::label $w.gl.l1 -textvar ::tr(GameLength:)
+  ttk::label $w.gl.l2 -text "-"
+  ttk::label $w.gl.l3 -textvar ::tr(HalfMoves)
+  ttk::entry $w.gl.emin -textvariable sGlMin -justify right -width 4
+  ttk::entry $w.gl.emax -textvariable sGlMax -justify right -width 4
   bindFocusColors $w.gl.emin
   bindFocusColors $w.gl.emax
   pack $w.gl -in $w.res -side right -fill x
   pack $w.gl.l1 $w.gl.emin $w.gl.l2 $w.gl.emax $w.gl.l3 -side left
   
-  ttk::label $w.ends.label -textvar ::tr(EndSideToMove:) -font $bold
-  ttk::frame $w.ends.sep1 -width 5
-  ttk::frame $w.ends.sep2 -width 5
-  ttk::radiobutton $w.ends.white -textvar ::tr(White) -variable sSideToMove -value w
-  ttk::radiobutton $w.ends.black -textvar ::tr(Black) -variable sSideToMove -value b
-  ttk::radiobutton $w.ends.both -textvar ::tr(Both) -variable sSideToMove -value wb
-  pack $w.ends.label $w.ends.white $w.ends.sep1 $w.ends.black $w.ends.sep2 $w.ends.both -side left
-  pack $w.ends -side top -fill x
+  ttk::label $w.ends.label -textvar ::tr(EndSideToMove)
+  ttk::checkbutton $w.ends.white -textvar ::tr(White) -variable sSideToMoveW -offvalue "" -onvalue w
+  ttk::checkbutton $w.ends.black -textvar ::tr(Black) -variable sSideToMoveB -offvalue "" -onvalue b
+  pack $w.ends.label $w.ends.white $w.ends.black -side left -padx "0 5"
+  pack $w.ends -side top -fill x -in $w.result
   
-  addHorizontalRule $w
-  
-  pack .sh.ano -side top -fill x
-  ttk::label $w.ano.a1 -textvar ::tr(Annotations:) -font $bold
-  ttk::label $w.ano.a2 -textvar ::tr(Annotator:) -font $bold
-  ttk::checkbutton $w.ano.an -textvar ::tr(Cmnts:) -variable sAnnotated -offvalue 0 -onvalue 1
-  ttk::entry $w.ano.aname -textvariable sAnnotator -width 20 -font $regular
-  pack $w.ano.a1 $w.ano.an -side left
-  pack $w.ano.aname $w.ano.a2 -side right
+  pack $w.ano -side top -fill x
+  ttk::label $w.ano.a1 -textvar ::tr(Annotations:)
+  ttk::label $w.ano.a2 -textvar ::tr(Annotator:)
+  ttk::checkbutton $w.ano.an -textvar ::tr(Cmnts) -variable sAnnotated -offvalue 0 -onvalue 1
+  ttk::entry $w.ano.aname -textvariable sAnnotator -width 20
+  pack $w.ano.a1 $w.ano.an -side left -padx "0 5"
+  pack $w.ano.aname $w.ano.a2 -side right -padx "5 0"
 
   addHorizontalRule $w
   
-  ttk::label $w.eco.l1 -textvar ::tr(ECOCode:) -font $bold
-  ttk::label $w.eco.l2 -text "-" -font $regular
-  ttk::label $w.eco.l3 -text " " -font $regular
-  ttk::label $w.eco.l4 -textvar ::tr(GamesWithNoECO:) -font $bold
-  ttk::entry $w.eco.emin -textvariable sEcoMin -width 5 -font $regular
-  ttk::entry $w.eco.emax -textvariable sEcoMax -width 5 -font $regular
+  ttk::label $w.eco.l1 -textvar ::tr(ECOCode:)
+  ttk::label $w.eco.l2 -text "-"
+  ttk::label $w.eco.l3 -text " "
+  ttk::entry $w.eco.emin -textvariable sEcoMin -width 5
+  ttk::entry $w.eco.emax -textvariable sEcoMax -width 5
   bindFocusColors $w.eco.emin
   bindFocusColors $w.eco.emax
   ttk::button $w.eco.range -text "..." -style  Pad0.Small.TButton -width 0 -command {
@@ -283,26 +295,27 @@ proc search::header {{ref_base ""} {ref_filter ""}} {
     }
     unset tempResult
   }
-  ttk::radiobutton $w.eco.yes -variable sEco -value Yes -textvar ::tr(Yes) -style Small.TRadiobutton
-  ttk::radiobutton $w.eco.no -variable sEco -value No -textvar ::tr(No) -style Small.TRadiobutton
-  pack $w.eco -side top -fill x
-  pack $w.eco.l1 $w.eco.emin $w.eco.l2 $w.eco.emax $w.eco.range $w.eco.l3 $w.eco.l4 $w.eco.yes $w.eco.no -side left
+  ttk::checkbutton $w.eco.yes -variable sEco -onvalue Yes -offvalue No -textvar ::tr(GamesWithNoECO)
+  pack $w.eco -side top -fill x -pady "5 0"
+  pack $w.eco.l1 $w.eco.emin $w.eco.l2 $w.eco.emax -side left
+  pack $w.eco.range -side left -padx "5 10"
+  pack $w.eco.l3 $w.eco.yes -side left
   
   set f [ttk::frame $w.gnum]
   pack $f -side top -fill x
-  ttk::label $f.l1 -textvar ::tr(GlistGameNumber:) -font $bold
-  ttk::entry $f.emin -textvariable sGnumMin -width 8 -justify right -font $regular
+  ttk::label $f.l1 -textvar ::tr(GlistGameNumber:)
+  ttk::entry $f.emin -textvariable sGnumMin -width 8 -justify right
   ttk::label $f.l2 -text "-" -font $regular
-  ttk::entry $f.emax -textvariable sGnumMax -width 8 -justify right -font $regular
+  ttk::entry $f.emax -textvariable sGnumMax -width 8 -justify right
   pack $f.l1 $f.emin $f.l2 $f.emax -side left
   bindFocusColors $f.emin
   bindFocusColors $f.emax
-  ttk::label $f.l3 -text " " -font $regular
-  ttk::button $f.all -text [::utils::string::Capital $::tr(all)] -style Pad0.Small.TButton -command {set sGnumMin 1; set sGnumMax -1}
+  ttk::label $f.l3 -text " "
+  ttk::button $f.all -text [::utils::string::Capital $::tr(all)] -style Pad0.Small.TButton -command {set sGnumMin ""; set sGnumMax ""}
   ttk::menubutton $f.first -style pad0.TMenubutton -textvar ::tr(First...) -menu $f.first.m
   ttk::menubutton $f.last -style pad0.TMenubutton -textvar ::tr(Last...) -menu $f.last.m
-  menu $f.first.m -font $regular
-  menu $f.last.m -font $regular
+  menu $f.first.m
+  menu $f.last.m
   foreach x {10 50 100 500 1000 5000 10000} {
     $f.first.m add command -label $x \
         -command "set sGnumMin 1; set sGnumMax $x"
@@ -313,127 +326,182 @@ proc search::header {{ref_base ""} {ref_filter ""}} {
   
   set f [ttk::frame $w.pgntext]
   pack $f -side top -fill x
-  ttk::label $f.l1 -textvar ::tr(PgnContains:) -font $bold
-  ttk::entry $f.e1 -textvariable sPgntext(1) -width 15 -font $regular
+  ttk::label $f.l1 -textvar ::tr(PgnContains:)
+  ttk::entry $f.e1 -textvariable sPgntext(1) -width 15
   ttk::label $f.l2 -text "+" -font $regular
-  ttk::entry $f.e2 -textvariable sPgntext(2) -width 15 -font $regular
+  ttk::entry $f.e2 -textvariable sPgntext(2) -width 15
   ttk::label $f.l3 -text "+" -font $regular
-  ttk::entry $f.e3 -textvariable sPgntext(3) -width 15 -font $regular
+  ttk::entry $f.e3 -textvariable sPgntext(3) -width 15
   bindFocusColors $f.e1
   bindFocusColors $f.e2
   bindFocusColors $f.e3
-  pack $f.l1 $f.e1 $f.l2 $f.e2 $f.l3 $f.e3 -side left
+  pack $f.l1 $f.e1 $f.l2 $f.e2 $f.l3 $f.e3 -side left -pady "0 5"
   
   addHorizontalRule $w
   
-  ttk::button $w.flagslabel -textvar ::tr(FindGamesWith:) -style Pad0.Small.TButton -image tb_menu -compound left -command {
-    if {$sHeaderFlagFrame} {
-      set sHeaderFlagFrame 0
-      pack forget .sh.flags
+  ttk::button $w.flagslabel -textvar ::tr(FindGamesWith:) -style Pad0.Small.TButton -image tb_menu -compound left -command "
+    if {\$::sHeaderFlagFrame} {
+      set ::sHeaderFlagFrame 0
+      pack forget $w.flags
     } else {
-      set sHeaderFlagFrame 1
-      pack .sh.flags -side top -after .sh.flagslabel
+      set ::sHeaderFlagFrame 1
+      pack $w.flags -side top -after $w.flagslabel -pady 5 -fill x
     }
-  }
-  pack $w.flagslabel -side top -fill x
-  
+  "
+  pack $w.flagslabel -side top -fill x -pady "5 5"
+
   ttk::frame $w.flags
   if {$::sHeaderFlagFrame} {
-    pack $w.flags -side top
+    pack $w.flags -side top -pady 5 -fill x
   }
   
-  set count 0
   set row 0
   set col 0
-  foreach var $::sHeaderFlagList {   
-    set lab [ttk::label $w.flags.l$var -text  [ ::tr $var ] -font font_Small]
-    grid $lab -row $row -column $col -sticky e
+  foreach var [concat $::sHeaderFlagList $::sHeaderCustomFlagList] {
+    grid [ttk::label $w.flags.l$var -text [::tr $var] -font font_Small] -row $row -column $col -sticky w
     incr col
     grid [ttk::radiobutton $w.flags.yes$var -variable sHeaderFlags($var) -value yes -text $::tr(Yes)] -row $row -column $col
     incr col
     grid [ttk::radiobutton $w.flags.no$var -variable sHeaderFlags($var) -value no -text $::tr(No)] -row $row -column $col
     incr col
     grid [ttk::radiobutton $w.flags.both$var -variable sHeaderFlags($var) -value both -text $::tr(Both)] -row $row -column $col
-    incr count
     incr col -3
     incr row
-    if {$count == 6} { set col 5; set row 0 }
-    if {$count == 12} { set col 10; set row 0 }
+    if {$row == 12} {
+      set col 5
+      set row 0
+    }
   }
-  
+  grid columnconfigure $w.flags 4 -weight 1
+
+  #TODO: ref_base should be used instead of curr_db
   set ::curr_db [sc_base current]
-  set count 1
-  set col 0
-  set row 7
-  foreach var $::sHeaderCustomFlagList {
-    
-    set lb [sc_base extra $::curr_db flag$count]
-    if { $lb == ""  } {  set lb $var  }
-    
-    set lab [ttk::label $w.flags.l$var -text $lb -font font_Small]
-    grid $lab -row $row -column $col -sticky e
-    incr col
-    grid [ttk::radiobutton $w.flags.yes$var -variable sHeaderFlags($var) -value yes -text $::tr(Yes)] -row $row -column $col
-    incr col
-    grid [ttk::radiobutton $w.flags.no$var -variable sHeaderFlags($var) -value no -text $::tr(No)] -row $row -column $col
-    incr col
-    grid [ttk::radiobutton $w.flags.both$var -variable sHeaderFlags($var) -value both -text $::tr(Both)] -row $row -column $col
-    incr col 2
-    incr count
-    if {$count == 4} { set col 0; set row 8 }
+  foreach {tagname tagvalue} [sc_base extra $::curr_db] {
+    if { $tagvalue ne "" && [regexp {flag([1-6])} $tagname -> i] } {
+      $w.flags.lCustomFlag$i configure -text $tagvalue
+    }
   }
-  
-  grid [ttk::label $w.flags.space -text "" -font $regular] -row 0 -column 4
-  grid [ttk::label $w.flags.space2 -text "" -font $regular] -row 0 -column 9
-  
-  addHorizontalRule $w
-  ::search::addFilterOpFrame $w 1
-  addHorizontalRule $w
-  
-  ### Header search: search/cancel buttons
-  
-  ttk::frame $w.b
-  pack $w.b -side top -fill both
-  ttk::button $w.b.defaults -textvar ::tr(Defaults) -command ::search::header::defaults ;# -padx 20
-  ttk::button $w.b.save -textvar ::tr(Save...) -command ::search::header::save ;# -padx 20
-  ttk::button $w.b.stop -textvar ::tr(Stop) -command progressBarCancel
-  ttk::button $w.b.search -textvar ::tr(Search) -command {
-    ::utils::history::AddEntry HeaderSearchWhite $sWhite
-    ::utils::history::AddEntry HeaderSearchBlack $sBlack
-    ::utils::history::AddEntry HeaderSearchEvent $sEvent
-    ::utils::history::AddEntry HeaderSearchSite $sSite
-    
+
+  return "::search::headerGetOptions"
+}
+
+proc ::search::headerGetOptions {{cmd ""}} {
+	if {$cmd eq "reset"} {
+		::search::header::defaults
+		return
+	}
+
+	::utils::history::AddEntry HeaderSearchWhite $::sWhite
+	::utils::history::AddEntry HeaderSearchBlack $::sBlack
+	::utils::history::AddEntry HeaderSearchEvent $::sEvent
+	::utils::history::AddEntry HeaderSearchSite $::sSite
+
+	set options {header}
+	::search::headerPlayerOptions options -white -welo -black -belo
+
+	set invert_col 0
+	if {$::sIgnoreCol == "Yes" && [llength $options] > 1} { set invert_col 1 }
+
+	::search::getSearchOptions options
+	if {! $invert_col } {
+		return [list $options]
+	}
+
+	set options2 {header}
+	::search::headerPlayerOptions options2 -black -belo -white -welo
+	::search::getSearchOptions options2
+	return [list $options $options2]
+}
+
+proc ::search::getRange {var_min var_max cmd_min cmd_max} {
+	if {[set $var_min] ne ""} {
+		if {[set $var_max] ne ""} {
+			return [list [set $var_min] [set $var_max]]
+		}
+		return [list [set $var_min] [subst $cmd_max]]
+	} elseif {[set $var_max] ne ""} {
+		return [list [subst $cmd_min] [set $var_max]]
+	}
+	return {}
+}
+
+proc ::search::headerPlayerOptions {dest_list white welo black belo} {
+	upvar $dest_list options
+
+	if {$::sWhite ne ""} { lappend options $white $::sWhite }
+
+	if {$::sBlack ne ""} { lappend options $black $::sBlack	}
+
+	set range [::search::getRange ::sWhiteEloMin ::sWhiteEloMax 0 "\[sc_info limit elo\]"]
+	if {$range ne ""} { lappend options $welo $range }
+
+	set range [::search::getRange ::sBlackEloMin ::sBlackEloMax 0 "\[sc_info limit elo\]"]
+	if {$range ne ""} { lappend options $belo $range }
+}
+
+### Read values from header search dialog. Use empty string as "all"
+proc ::search::getSearchOptions {dest_list} {
+	upvar $dest_list search
+
+	if {$::sEvent ne ""} { lappend search "-event" $::sEvent }
+
+	if {$::sSite ne ""} { lappend search "-site" $::sSite }
+
+	if {$::sRound ne ""} { lappend search "-round" $::sRound }
+
+	set range [::search::getRange ::sGnumMin ::sGnumMax 0 -1]
+	if {$range ne ""} { lappend search "-gnum" $range }
+
+	set range [::search::getRange ::sGlMin ::sGlMax 0 999]
+	if {$range ne ""} { lappend search "-length" $range }
+
+	set range [::search::getRange ::sDateMin ::sDateMax "1800.01.01" "\[sc_info limit year\].12.31"]
+	if {$range ne ""} { lappend search "-date" $range }
+
+	set range [::search::getRange ::sEventDateMin ::sEventDateMax "1800.01.01" "\[sc_info limit year\].12.31"]
+	if {$range ne ""} { lappend search "-eventdate" $range }
+
+	set range [::search::getRange ::sEloDiffMin ::sEloDiffMax "-\[sc_info limit elo\]" "\[sc_info limit elo\]"]
+	if {$range ne ""} {
+		lappend search "-delo" $range
+		if {$::sIgnoreCol == "Yes"} {
+			lassign $range elo_min elo_max
+			lappend search "-delo|" [list [expr -1 * $elo_max] [expr -1 * $elo_min]]
+		}
+	}
+
+	set range [::search::getRange ::sEcoMin ::sEcoMax A00 E99]
+	if {$range ne ""} {
+		lappend search "-eco" $range
+		if {$::sEco eq "Yes"} { lappend search "-eco|" [list 0 0] }
+	}
+	if {$::sEco ne "Yes"} { lappend search "-eco!" [list 0 0] }
+
+	set wtitles {}
+	set btitles {}
+	foreach i $::sTitleList {
+	  if $::sTitles(w:$i) { lappend wtitles $i }
+	  if $::sTitles(b:$i) { lappend btitles $i }
+	}
+	if {[llength $wtitles] != 8} { lappend search -wtitles $wtitles }
+	if {[llength $btitles] != 8} { lappend search -btitles $btitles }
+
+	if {$::sSideToMoveW eq "" || $::sSideToMoveB eq ""} {
+		lappend search -toMove "$::sSideToMoveW$::sSideToMoveB"
+	}
+
+	if {$::sAnnotated} { lappend search "-annotated" $::sAnnotated }
+
+	if {$::sAnnotator ne ""} { lappend search "-annotator" $::sAnnotator }
+
+    global sHeaderFlags
+    global sResWin sResLoss sResDraw sResOther sPgntext
+
     set sPgnlist {}
     foreach i {1 2 3} {
       set temp [string trim $sPgntext($i)]
       if {$temp != ""} { lappend sPgnlist $temp }
     }
-    pack .sh.b.stop -side right -padx 5
-    grab .sh.b.stop
-    set wtitles {}
-    set btitles {}
-    foreach i $sTitleList {
-      if $sTitles(w:$i) { lappend wtitles $i }
-      if $sTitles(b:$i) { lappend btitles $i }
-    }
-    
-    set dbase [string index $::refDatabaseH 0]
-    if {$::refFilterH == ""} {
-        set filter "dbfilter"
-    } else {
-        set filter [sc_filter link $dbase $::refFilterH]
-    }
-
-    if {$sEco == "Yes"} {
-        set noEco "-eco|"
-    } else {
-        set noEco "-eco!"
-    }
-
-    if {$::search::filter::operation != "2" } {
-        set fOrig [sc_filter new $dbase]
-        sc_filter copy $dbase $fOrig $filter
-    }
 
     set flagsYes ""
     set flagsNo ""
@@ -451,6 +519,13 @@ proc search::header {{ref_base ""} {ref_filter ""}} {
         }
     }
 
+    set results ""
+    append results $sResWin $sResDraw $sResLoss $sResOther
+    foreach { i j} { -result! results -flag flagsYes -flag! flagsNo -pgn sPgnlist} {
+	if { [llength [set $j]] > 0 } {
+	    lappend search $i [set $j]
+	}
+    }
     set fCounts(Variations) "-n_variations"
     set fCountsV(Variations) ""
     set fCounts(Comments) "-n_comments"
@@ -461,119 +536,19 @@ proc search::header {{ref_base ""} {ref_filter ""}} {
         if  { $sHeaderFlags($i) == "yes" } {
              append fCounts($i) "!"
              set fCountsV($i) "0"
+	     lappend search $fCounts($i) $fCountsV($i)
         } elseif  { $sHeaderFlags($i) == "no" } {
              set fCountsV($i) "0"
+	     lappend search $fCounts($i) $fCountsV($i)
         }
     }
-
-    set results ""
-    append results $sResWin
-    append results $sResDraw
-    append results $sResLoss
-    append results $sResOther
-
-    progressBarSet .sh.fprogress.progress 301 21
-    set err [catch { sc_filter search $dbase $filter header \
-          -filter RESET \
-          -white $sWhite -black $sBlack \
-          -event $sEvent -site $sSite -round $sRound \
-          -date [list $sDateMin $sDateMax] \
-          -result! $results \
-          -welo [list $sWhiteEloMin $sWhiteEloMax] \
-          -belo [list $sBlackEloMin $sBlackEloMax] \
-          -delo [list $sEloDiffMin $sEloDiffMax] \
-          -eco [list $sEcoMin $sEcoMax] $noEco [list 0 0] \
-          -length [list $sGlMin $sGlMax] \
-          -toMove $sSideToMove \
-          -gnum [list $sGnumMin $sGnumMax] \
-          -annotated $sAnnotated \
-          -annotator $sAnnotator \
-          -flag $flagsYes -flag! $flagsNo \
-          $fCounts(Variations) $fCountsV(Variations) \
-          $fCounts(Comments) $fCountsV(Comments) \
-          $fCounts(Annotations) $fCountsV(Annotations) \
-          -pgn $sPgnlist -wtitles $wtitles -btitles $btitles \
-    }]
-
-    if {!$err && $sIgnoreCol == "Yes"} {
-        set fIgnore [sc_filter new $dbase]
-        set deloMin [ expr { $sEloDiffMax * -1 }]
-        set deloMax [ expr { $sEloDiffMin * -1 }]
-        progressBarSet .sh.fprogress.progress 301 21
-        catch { sc_filter search $dbase $fIgnore header \
-          -filter RESET \
-          -white $sBlack -black $sWhite \
-          -event $sEvent -site $sSite -round $sRound \
-          -date [list $sDateMin $sDateMax] \
-          -result! $results \
-          -welo [list $sBlackEloMin $sBlackEloMax] \
-          -belo [list $sWhiteEloMin $sWhiteEloMax] \
-          -delo [list $deloMin $deloMax] \
-          -eco [list $sEcoMin $sEcoMax] $noEco [list 0 0] \
-          -length [list $sGlMin $sGlMax] \
-          -toMove $sSideToMove \
-          -gnum [list $sGnumMin $sGnumMax] \
-          -annotated $sAnnotated \
-          -annotator $sAnnotator \
-          -flag $flagsYes -flag! $flagsNo \
-          $fCounts(Variations) $fCountsV(Variations) \
-          $fCounts(Comments) $fCountsV(Comments) \
-          $fCounts(Annotations) $fCountsV(Annotations) \
-          -pgn $sPgnlist -wtitles $wtitles -btitles $btitles \
-        }
-
-        sc_filter or $dbase $filter $fIgnore
-        sc_filter release $dbase $fIgnore
-    }
-
-    if {[info exists fOrig]} {
-        if {$::search::filter::operation == "0" } {
-            sc_filter and $dbase $filter $fOrig
-        } else {
-            sc_filter or $dbase $filter $fOrig
-        }
-        sc_filter release $dbase $fOrig
-        unset fOrig
-    }
-
-    set str "[sc_filter count $dbase $filter] / [sc_base numGames $dbase]"
-
-    after idle "::notify::DatabaseModified $dbase dbfilter"
-    
-    grab release .sh.b.stop
-    pack forget .sh.b.stop
-    .sh.status configure -text $str
-
-  }
-  
-  ttk::button $w.b.cancel -textvar ::tr(Close) -command {focus .; destroy .sh} ;# -padx 20
-  
-  foreach i {defaults save cancel search stop} {
-    $w.b.$i configure -style Small.TButton
-    
-    pack $w.b.defaults $w.b.save -side left -padx 5
-    pack $w.b.cancel $w.b.search -side right -padx 5
-  }
-  
-  pack [ ttk::frame $w.fprogress ] -fill both
-  canvas $w.fprogress.progress -height 20 -width 300 -bg white -relief solid -border 1
-  $w.fprogress.progress create rectangle 0 0 0 0 -fill blue -outline blue -tags bar
-  $w.fprogress.progress create text 295 10 -anchor e -font font_Regular -tags time \
-      -fill black -text "0:00 / 0:00"
-  pack $w.fprogress.progress -side top -pady 2
-  ttk::label $w.status -text "" -width 1 -font font_Small -relief sunken -anchor w
-  pack $w.status -side bottom -fill x
-  # update
-  wm resizable $w 0 0
-  ::search::Config
-  focus $w.cWhite.e
 }
 
 proc ::search::header::save {} {
   global sWhite sBlack sEvent sSite sRound sAnnotator sAnnotated sDateMin sDateMax sIgnoreCol
   global sWhiteEloMin sWhiteEloMax sBlackEloMin sBlackEloMax
   global sEloDiffMin sEloDiffMax sGlMin sGlMax
-  global sEco sEcoMin sEcoMax sHeaderFlags sSideToMove
+  global sEco sEcoMin sEcoMax sHeaderFlags sSideToMoveW sSideToMoveB
   global sResWin sResLoss sResDraw sResOther sPgntext
   
   set ftype { { "Scid SearchOptions files" {".sso"} } }
@@ -591,12 +566,13 @@ proc ::search::header::save {} {
   }
   puts $searchF "\# SearchOptions File created by Scid $::scidVersion"
   puts $searchF "set searchType Header"
-  
+  getSearchEntries
+
   # First write the regular variables:
   foreach i {sWhite sBlack sEvent sSite sRound sAnnotator sAnnotated sDateMin sDateMax sResWin
     sResLoss sResDraw sResOther sWhiteEloMin sWhiteEloMax sBlackEloMin
     sBlackEloMax sEcoMin sEcoMax sEloDiffMin sEloDiffMax
-    sIgnoreCol sSideToMove sGlMin sGlMax ::search::filter::operation} {
+    sIgnoreCol sSideToMoveW sSideToMoveB sGlMin sGlMax ::search::filter::operation} {
     puts $searchF "set $i [list [set $i]]"
   }
   # Now write the array values:
@@ -704,10 +680,9 @@ proc chooseEcoRange {} {
       set scid_ecoRangeChosen [lindex $ecoCommonRanges [lindex $sel 0]]
       set ::sEco No
     }
-    focus .sh
     destroy .ecoRangeWin
   }
-  ttk::button $w.b.cancel -text $::tr(Cancel) -command "focus .sh; destroy $w"
+  ttk::button $w.b.cancel -text $::tr(Cancel) -command "destroy $w"
   pack $w.b.cancel $w.b.ok -side right -padx 5 -pady 2
   bind $w <Escape> "
   set scid_ecoRangeChosen {}
@@ -723,7 +698,6 @@ proc chooseEcoRange {} {
   return $scid_ecoRangeChosen
 }
 
-
 ###
 ### End of file: search.tcl
 
