@@ -8,9 +8,6 @@ namespace eval tacgame {
   ### Tacgame window: uses a chess engine (Phalanx) in easy mode and
   ### another engine (for example Toga) to track blunders
   
-  ### many variables are now set in start.tcl to allow for
-  ### remembering them in options.dat S.A
-  
   set resignCount 0
   
   # if true, follow a specific opening
@@ -41,7 +38,6 @@ namespace eval tacgame {
   set lscore {}
   
   set analysisCoach(automove1) 0
-  set analysisCoach(paused) 0 ; # S.A
   
   # ======================================================================
   # resetValues
@@ -142,7 +138,7 @@ namespace eval tacgame {
       return
     }
     
-    toplevel $w
+    win::createDialog $w
     wm title $w "$::tr(configurecoachgame)"
     
     bind $w <F1> { helpWindow TacticalGame }
@@ -152,13 +148,13 @@ namespace eval tacgame {
     ttk::frame $w.flevel.diff_fixed
     ttk::frame $w.flevel.diff_random
     ttk::labelframe $w.fopening -text $::tr(Opening)
-    ttk::frame $w.flimit -relief raised -borderwidth 1
+    ttk::labelframe $w.flimit -text $::tr(Time)
     ttk::frame $w.fbuttons
     
     pack $w.flevel -side top -fill x
-    pack $w.flevel.diff_fixed -side top
-    pack $w.flevel.diff_random -side top
-    pack $w.fopening  -side top -fill both -expand 1
+    pack $w.flevel.diff_fixed -side top -anchor w
+    pack $w.flevel.diff_random -side top -anchor w
+    pack $w.fopening  -side top -fill both -expand 1 -pady 10
     pack $w.flimit $w.fbuttons -side top -fill x
     
     ttk::radiobutton $w.flevel.diff_random.cb -text $::tr(RandomLevel) -variable ::tacgame::randomLevel -value 1 -width 15
@@ -168,21 +164,19 @@ namespace eval tacgame {
     ttk::scale $w.flevel.diff_random.lMax -orient horizontal -from 1200 -to 2200 -length 100 -variable ::tacgame::levelMax \
         -command { ::utils::validate::roundScale ::tacgame::levelMax 50 }
     ttk::label $w.flevel.diff_random.labelMax -textvariable ::tacgame::levelMax
-    
-    grid $w.flevel.diff_random.cb -row 0 -column 0 -rowspan 2
-    grid $w.flevel.diff_random.labelMin -row 0 -column 1
-    grid $w.flevel.diff_random.lMin -row 1 -column 1
-    grid $w.flevel.diff_random.labelMax -row 0 -column 2
-    grid $w.flevel.diff_random.lMax -row 1 -column 2
-    
     ttk::radiobutton $w.flevel.diff_fixed.cb -text $::tr(FixedLevel) -variable ::tacgame::randomLevel -value 0 -width 15
     ttk::label $w.flevel.diff_fixed.labelFixed -textvariable ::tacgame::levelFixed
     ttk::scale $w.flevel.diff_fixed.scale -orient horizontal -from 1200 -to 2200 -length 200 \
         -variable ::tacgame::levelFixed -command { ::utils::validate::roundScale ::tacgame::levelFixed 50 }
     
     grid $w.flevel.diff_fixed.cb -row 0 -column 0 -rowspan 2
-    grid $w.flevel.diff_fixed.labelFixed -row 0 -column 1 -columnspan 2
-    grid $w.flevel.diff_fixed.scale -row 1 -column 1 -columnspan 2
+    grid $w.flevel.diff_fixed.labelFixed -row 0 -column 1
+    grid $w.flevel.diff_fixed.scale -row 1 -column 1 -padx "10 0" -sticky e
+    grid $w.flevel.diff_random.cb -row 0 -column 0 -rowspan 2
+    grid $w.flevel.diff_random.labelMin -row 0 -column 1
+    grid $w.flevel.diff_random.lMin -row 1 -column 1 -padx "10 0" -sticky e
+    grid $w.flevel.diff_random.labelMax -row 0 -column 2
+    grid $w.flevel.diff_random.lMax -row 1 -column 2 -sticky e
     
     # start new game
     ttk::radiobutton $w.fopening.cbNew -text $::tr(StartNewGame)  -variable ::tacgame::openingType -value new
@@ -193,9 +187,9 @@ namespace eval tacgame {
     # or choose a specific opening
     ttk::radiobutton $w.fopening.cbSpecific -text $::tr(SpecificOpening) -variable ::tacgame::openingType -value specific
     
-    pack $w.fopening.cbNew -anchor w -padx 100
-    pack $w.fopening.cbPosition -anchor w -padx 100
-    pack $w.fopening.cbSpecific -anchor w -padx 100
+    pack $w.fopening.cbNew -anchor w
+    pack $w.fopening.cbPosition -anchor w
+    pack $w.fopening.cbSpecific -anchor w
     
     ttk::frame $w.fopening.fOpeningList
     listbox $w.fopening.fOpeningList.lbOpening -yscrollcommand "$w.fopening.fOpeningList.ybar set" \
@@ -204,7 +198,7 @@ namespace eval tacgame {
     $w.fopening.fOpeningList.lbOpening see $::tacgame::chosenOpening
     
     ttk::scrollbar $w.fopening.fOpeningList.ybar -command "$w.fopening.fOpeningList.lbOpening yview"
-    pack $w.fopening.fOpeningList.lbOpening -side right -fill both -expand 1
+    pack $w.fopening.fOpeningList.lbOpening -side left -fill both -expand 1
     pack $w.fopening.fOpeningList.ybar  -side right -fill y
     pack $w.fopening.fOpeningList -expand yes -fill both -side top -expand 1
     
@@ -213,11 +207,11 @@ namespace eval tacgame {
     ttk::label $w.flimit.labelsecval -textvariable ::tacgame::analysisTime
     ttk::label $w.flimit.labelsec -text $::tr(seconds)
     ttk::scale $w.flimit.analysisTime -orient horizontal -from 5 -to 60 -length 200 -variable ::tacgame::analysisTime \
-        -command { ::utils::validate::roundScale ::tacgame::analysisTime 5 }
-    grid $w.flimit.blimit -column 0 -row 0 -rowspan 2
-    grid $w.flimit.labelsecval  -column 1 -row 0
-    grid $w.flimit.labelsec -column 2 -row 0
-    grid $w.flimit.analysisTime -column 1 -row 1 -columnspan 2
+        -command { ::utils::validate::roundScale ::tacgame::analysisTime 1 }
+    grid $w.flimit.blimit -column 0 -row 0 -columnspan 2 -sticky we
+    grid $w.flimit.labelsecval  -column 0 -row 1 -sticky e
+    grid $w.flimit.labelsec -column 1 -row 1 -sticky w -padx 5
+    grid $w.flimit.analysisTime -column 0 -row 2 -columnspan 2 -sticky we
     # pack $w.flimit.blimit $w.flimit.labelsec $w.flimit.analysisTime  $w.flimit.labelsecval -side left -expand yes -pady 5
     
     ttk::button $w.fbuttons.close -text $::tr(Play) -command {
@@ -228,7 +222,7 @@ namespace eval tacgame {
     }
     ttk::button $w.fbuttons.cancel -textvar ::tr(Cancel) -command "focus .; destroy $w"
     
-    pack $w.fbuttons.close $w.fbuttons.cancel -expand yes -side left -padx 20 -pady 2
+    packdlgbuttons $w.fbuttons.cancel $w.fbuttons.close
     
     bind $w <Escape> { .configWin.fbuttons.cancel invoke }
     bind $w <Return> { .configWin.fbuttons.close invoke }
@@ -249,14 +243,16 @@ namespace eval tacgame {
         ::tacgame::openingType ::tacgame::openingList ::tacgame::openingMovesList \
         ::tacgame::openingMovesHash ::tacgame::openingMoves ::tacgame::outOfOpening
     
+    if {$::tacgame::openingType ne "current"} {
+      if {[::game::Clear] eq "cancel"} { return }
+    }
+
     resetEngine 1
     resetEngine 2
     catch { unset ::uci::uciInfo(score2) }
     
     set ::tacgame::lFen {}
     
-    set analysisCoach(paused) 0
-    
     set w .coachWin
     if {[winfo exists $w]} {
       focus .
@@ -272,7 +268,7 @@ namespace eval tacgame {
       }
       set level [expr int(rand()*($::tacgame::levelMax - $::tacgame::levelMin)) + $::tacgame::levelMin ]
     } else {
-      set level $::tacgame::levelFixed; # S.A.
+      set level $::tacgame::levelFixed
     }
     
     # if will follow a specific opening line
@@ -292,7 +288,6 @@ namespace eval tacgame {
         lappend openingMovesList [string trim [regsub {^[1-9]+\.} $m ""] ]
       }
       
-      sc_game new
       lappend openingMovesHash [sc_pos hash]
       foreach m  $openingMovesList {
         if {[catch {sc_move addSan $m}]} {
@@ -303,7 +298,6 @@ namespace eval tacgame {
     
     # create a new game if a DB is opened
     if {$::tacgame::openingType != "current"} {
-      sc_game new
       sc_game tags set -event "Tactical game"
       if { [::board::isFlipped .main.board] } {
         sc_game tags set -white "Phalanx - $level ELO"
@@ -311,51 +305,48 @@ namespace eval tacgame {
         sc_game tags set -black "Phalanx - $level ELO"
       }
       sc_game tags set -date [::utils::date::today]
-      if {[sc_base inUse [sc_base current]]} { catch {sc_game save 0}  }
     }
     
     ::notify::GameChanged
     
     createToplevel $w
+    applyThemeColor_background $w
     setTitle $w "$::tr(coachgame) (Elo $level)"
-    setWinLocation $w
     
-    ttk::frame $w.fdisplay -relief groove -borderwidth 1
-    ttk::frame $w.fthreshold -relief groove -borderwidth 1
-    ttk::frame $w.finformations -relief groove -borderwidth 1
-    ttk::frame $w.fclocks -relief raised -borderwidth 2
+    ttk::frame $w.fdisplay
+    ttk::frame $w.fthreshold
+    ttk::frame $w.finformations
+    ttk::labelframe $w.fclockw -text "$::tr(Time) $::tr(Player)"
+    ttk::labelframe $w.fclockb -text "$::tr(Time) $::tr(Engine)"
     ttk::frame $w.fbuttons
-    pack $w.fdisplay $w.fthreshold $w.finformations $w.fclocks $w.fbuttons -side top -expand yes -fill both
+    pack $w.fdisplay -side top -fill both -pady 5 -padx 10
+    pack [ttk::separator $w.line1 -orient horizontal] -side top -fill x -padx 10 -pady 5
+    pack $w.fthreshold -side top -fill both -pady 5 -padx 10
+    pack [ttk::separator $w.line2 -orient horizontal] -side top -fill x -padx 10 -pady 5
+    pack $w.finformations $w.fclockb $w.fclockw -side top -fill both -pady 5 -padx 10
+    pack $w.fbuttons -side top -pady "10 15"
     
     ttk::checkbutton $w.fdisplay.b1 -text $::tr(showblunderexists) -variable ::tacgame::showblunder
     ttk::checkbutton $w.fdisplay.b2 -text $::tr(showblundervalue) -variable ::tacgame::showblundervalue
     ttk::checkbutton $w.fdisplay.b5 -text $::tr(showscore) -variable ::tacgame::showevaluation
-    pack $w.fdisplay.b1 $w.fdisplay.b2 $w.fdisplay.b5 -expand yes -anchor w
+    pack $w.fdisplay.b1 $w.fdisplay.b2 $w.fdisplay.b5 -anchor w
     
     ttk::label $w.fthreshold.l -text $::tr(moveblunderthreshold) -wraplength 300
     
     ttk::scale $w.fthreshold.t -orient horizontal -from 0.0 -to 10.0 -length 200 \
         -variable ::tacgame::threshold -command { ::utils::validate::floatScale ::tacgame::threshold 0.1 }
     ttk::label $w.fthreshold.labelt -textvariable ::tacgame::threshold
-    pack $w.fthreshold.l $w.fthreshold.labelt $w.fthreshold.t -side top
-    
+    pack $w.fthreshold.l $w.fthreshold.labelt $w.fthreshold.t -side top -anchor w
+
     ttk::label $w.finformations.l1 -textvariable ::tacgame::blunderWarningLabel -background linen
     ttk::label $w.finformations.l3 -textvariable ::tacgame::scoreLabel -foreground WhiteSmoke -background SlateGray
     pack $w.finformations.l1 $w.finformations.l3 -padx 5 -pady 5 -side top -fill x
     
-    ::gameclock::new $w.fclocks 2 80
-    ::gameclock::new $w.fclocks 1 80
+    ::gameclock::new $w.fclockb 2 80
+    ::gameclock::new $w.fclockw 1 80
     ::gameclock::reset 1
     ::gameclock::start 1
     
-    ### Resume restarts paused computer (while player moves forward/back in history) S.A.
-    ttk::button $w.fbuttons.resume -state disabled -textvar ::tr(Resume) -command {
-      set ::tacgame::analysisCoach(paused) 0
-      .coachWin.fbuttons.resume configure -state disabled
-      ::tacgame::phalanxGo
-    }
-    pack $w.fbuttons.resume -expand yes -fill both -padx 20 -pady 2
-    
     ttk::button $w.fbuttons.close -textvar ::tr(Abort) -command "destroy .coachWin"
     pack $w.fbuttons.close -expand yes -fill both -padx 20 -pady 2
     
@@ -370,7 +361,6 @@ namespace eval tacgame {
     bind $w <F1> { helpWindow TacticalGame }
     bind $w <Destroy> "if {\[string equal $w %W\]} {::tacgame::abortGame}"
     bind $w <Escape> "destroy .coachWin"
-    bind $w <Configure> "recordWinSize $w"
     wm minsize $w 45 0
     createToplevelFinalize $w
 
@@ -384,15 +374,30 @@ namespace eval tacgame {
     }
     return 0
   }
+
+  proc toggleClocks {} {
+    if {[::gameclock::stop 1]} {
+      ::gameclock::storeTimeComment 1
+      ::gameclock::start 2
+    } elseif {[::gameclock::stop 2]} {
+      ::gameclock::storeTimeComment 2
+      ::gameclock::start 1
+    }
+    ::notify::PosChanged -pgn -animate
+  }
+
+
   ################################################################################
   #
   ################################################################################
   proc abortGame { { destroyWin 1 } } {
-    unset ::playMode
+    catch { unset ::playMode }
     after cancel ::tacgame::phalanxGo
     stopAnalyze
     ::tacgame::closeEngine 1
     ::tacgame::closeEngine 2
+    ::gameclock::stop 1
+    ::gameclock::stop 2
     ::notify::GameChanged
   }
   # ======================================================================
@@ -593,8 +598,6 @@ namespace eval tacgame {
   ################################################################################
   proc endOfGame {} {
     if { [string index [sc_game info previousMove] end ] == "#"} {
-      ::gameclock::stop 1
-      ::gameclock::stop 2
       return 1
     }
     return 0
@@ -609,15 +612,11 @@ namespace eval tacgame {
     
     after cancel ::tacgame::phalanxGo
     
-    ### should show endOfGame
-    
-    if {$analysisCoach(paused)} {
-      .coachWin.fbuttons.resume configure -state normal
+    if { [::tacgame::endOfGame] } {
+      ::tacgame::abortGame
       return
     }
     
-    if { [::tacgame::endOfGame] } { return }
-    
     # check if Phalanx is already thinking
     if { $analysisCoach(automoveThinking1) == 1 } {
       after 1000 ::tacgame::phalanxGo
@@ -631,8 +630,7 @@ namespace eval tacgame {
       return
     }
     
-    ::gameclock::stop 1
-    ::gameclock::start 2
+    toggleClocks
     repetition
     
     # make a move corresponding to a specific opening, (it is Phalanx's turn)
@@ -650,9 +648,7 @@ namespace eval tacgame {
               -message "$::tr(NotFollowedLine) $openingMoves\n $::tr(DoYouWantContinue)" ]
           if {$answer == no} {
             sc_move back 1
-            updateBoard -pgn
-            ::gameclock::stop 2
-            ::gameclock::start 1
+            toggleClocks
             after 1000 ::tacgame::phalanxGo
             return
           }  else  {
@@ -686,9 +682,7 @@ namespace eval tacgame {
           
           ::utils::sound::AnnounceNewMove $move
           
-          updateBoard -pgn -animate
-          ::gameclock::stop 2
-          ::gameclock::start 1
+          toggleClocks
           repetition
           after 1000 ::tacgame::phalanxGo
           return
@@ -786,16 +780,17 @@ namespace eval tacgame {
       sc_var promote
       sc_move forward 1
     }
+    if { $::tacgame::showevaluation == 1 && [info exists ::uci::uciInfo(score2)] } {
+      storeEvalComment $::uci::uciInfo(score2)
+    }
     
     set analysisCoach(automoveThinking1) 0
     set currentPosHash [sc_pos hash]
     
     ::tacgame::startAnalyze
     ::utils::sound::AnnounceNewMove $move
-    updateBoard -pgn -animate
     
-    ::gameclock::stop 2
-    ::gameclock::start 1
+    toggleClocks
     repetition
     
     if { $resignCount > 3 } {
@@ -815,7 +810,7 @@ namespace eval tacgame {
       set ::tacgame::scoreLabel ""
       return
     } else {
-      set ::tacgame::scoreLabel "Score : $::uci::uciInfo(score2)"
+      set ::tacgame::scoreLabel "Score: $::uci::uciInfo(score2)"
     }
   }
   
