@@ -65,10 +65,17 @@ namespace eval tactics {
                 sc_filter search $baseId $filter header -filter AND -site "\"$::tactics::solved\""
                 set solvedCount [sc_filter count $baseId $filter]
 
-                set line [list [file tail $fname] [sc_base extra $baseId description] $solvedCount $nTactics]
+                set desc {}
+                foreach {tagname tagvalue} [sc_base extra $baseId] {
+                    if {$tagname eq "description"} {
+                        set desc $tagvalue
+                        break
+                    }
+                }
+                set line [list [file tail $fname] $desc $solvedCount $nTactics]
 
                 set pos "end"
-                if {[sc_base extra $baseId type] == 15} {
+                if {[getBaseType $baseId] == 15} {
                     if {![info exists nTactBases]} {
                         set nTactBases -1
                         set valid $fname
@@ -157,7 +164,7 @@ namespace eval tactics {
             focus $w
             return
         }
-        toplevel $w
+        win::createDialog $w
         wm title $w $::tr(ConfigureTactics)
         wm resizable $w 0 0
 
@@ -166,10 +173,10 @@ namespace eval tactics {
         $w.dummy create rectangle 0 0 0 0
 
         #Engine selection
-        grid [frame $w.sep1 -height 10] -sticky news -padx 10
-        label $w.engine -font font_Bold -text "[tr Engine]:"
-        grid $w.engine -sticky w -padx 10
-        grid [ttk::frame $w.e] -sticky news -padx 10
+        grid [ttk::frame $w.sep1 -height 10] -sticky news
+        ttk::label $w.engine -font font_Bold -text "[tr Engine]:"
+        grid $w.engine -sticky we
+        grid [ttk::frame $w.e] -sticky nwes
         ttk::treeview $w.e.engines -columns {0 1} -selectmode browse -show {} -height 4
         $w.e.engines column 0 -width 200
         $w.e.engines column 1 -width 400
@@ -192,29 +199,29 @@ namespace eval tactics {
         }
         autoscrollframe -bars both $w.e "" $w.e.engines
 
-        grid [ttk::frame $w.t] -sticky news -padx 10
+        grid [ttk::frame $w.t] -sticky news
         grid columnconfigure $w.t 2 -weight 1
-        label $w.t.analabel -text "[tr SecondsPerMove]: "
-        scale $w.t.analysisTime -orient horizontal -from 1 -to 60 -length 120 -variable ::tactics::analysisTime \
-                -showvalue 0 -command { ::utils::validate::roundScale ::tactics::analysisTime 1 }
-        label $w.t.value -textvar ::tactics::analysisTime
-        grid $w.t.analabel  $w.t.value $w.t.analysisTime -sticky news
+        ttk::label $w.t.analabel -text "[tr SecondsPerMove]: "
+        ttk::scale $w.t.analysisTime -orient horizontal -from 1 -to 60 -length 120 -variable ::tactics::analysisTime \
+                -command { ::utils::validate::roundScale ::tactics::analysisTime 1 }
+        ttk::label $w.t.value -textvar ::tactics::analysisTime
+        grid $w.t.analabel  $w.t.value $w.t.analysisTime -sticky nwes
         
 
         #BaseDir selection
-        grid [frame $w.sep2 -height 20] -sticky news -padx 10 -pady 10
-        grid [frame $w.d] -sticky news -padx 10 -pady 10
-        label $w.d.lbl -font font_Bold -text "[tr ChooseTrainingBase]:"
+        grid [ttk::frame $w.sep2 -height 20] -sticky nwes
+        grid [ttk::frame $w.d] -sticky news
+        ttk::label $w.d.lbl -font font_Bold -text "[tr ChooseTrainingBase]:"
         grid $w.d.lbl -sticky w -columnspan 3
         grid columnconfigure $w.d 1 -weight 1
-        button $w.d.selectDir -image tb_open -command "setTacticsBasesDir; ::tactics::configValidDir $w"
-        label $w.d.basedir -textvariable scidBasesDir
-        button $w.d.search -text [tr Search]
-        grid $w.d.selectDir $w.d.basedir $w.d.search -sticky w -padx 10
+        ttk::button $w.d.selectDir -image tb_open -command "setTacticsBasesDir; ::tactics::configValidDir $w"
+        ttk::label $w.d.basedir -textvariable scidBasesDir
+        ttk::button $w.d.search -text [tr Search]
+        grid $w.d.selectDir $w.d.basedir $w.d.search -sticky w
 
 
         #Base selection
-        grid [ttk::frame $w.s] -sticky news -padx 10
+        grid [ttk::frame $w.s] -sticky news
         ttk::treeview $w.s.bases -columns {0 1 2 3} -show headings -selectmode browse -height 8
         $w.s.bases tag configure empty -foreground #a5a2ac
         $w.s.bases heading 0 -text [tr DatabaseName]
@@ -229,7 +236,7 @@ namespace eval tactics {
 
         canvas $w.pbar -width 600 -height 10 -bg white -relief solid -border 1
         $w.pbar create rectangle 0 0 0 0 -fill blue -outline blue -tags bar
-        grid $w.pbar
+        grid $w.pbar -pady "0 5"
 
 
         #Buttons
@@ -240,9 +247,9 @@ namespace eval tactics {
         ttk::button $w.fbutton.reset -text [tr ResetScores]
         ttk::button $w.fbutton.help -text [tr Help] \
             -command "destroy $w; helpWindow TacticsTrainer"
-        grid $w.fbutton.ok -row 0 -column 2
+        grid $w.fbutton.ok -row 0 -column 2 -padx 10
         grid $w.fbutton.cancel -row 0 -column 3
-        grid $w.fbutton.reset -row 0 -column 1 -sticky w
+        grid $w.fbutton.reset -row 0 -column 1 -sticky w -padx 10
         grid $w.fbutton.help -row 0 -column 0 -sticky w
 
         # Set up geometry for middle of screen:
@@ -275,7 +282,6 @@ namespace eval tactics {
         
         createToplevel $w .pgnWin
         setTitle $w $::tr(Tactics)
-        setWinLocation $w
         # because sometimes the 2 buttons at the bottom are hidden
         wm minsize $w 170 170
         ttk::frame $w.f1 -relief groove ;# -borderwidth 1
@@ -304,7 +310,6 @@ namespace eval tactics {
         ttk::button $w.fbuttons.close -textvar ::tr(Abort) -command "destroy $w"
         pack $w.fbuttons.next $w.fbuttons.close -expand yes -fill both -padx 20 -pady 2
         bind $w <Destroy> "if {\[string equal $w %W\]} {::tactics::endTraining}"
-        bind $w <Configure> "recordWinSize $w"
         bind $w <F1> { helpWindow TacticsTrainer }
         createToplevelFinalize $w
         
@@ -326,7 +331,7 @@ namespace eval tactics {
 
         #TODO:
         #sc_filter release $::tactics::baseId $::tactics::filter
-        sc_filter set $::tactics::baseId "dbfilter" 1
+        sc_filter reset $::tactics::baseId dbfilter full
         catch { ::uci::closeUCIengine $::tactics::engineSlot }
 
         unset ::playMode
