@@ -84,7 +84,7 @@ proc ::windows::gamelist::DatabaseModified {{dbase} {filter -1}} {
 			if {$filter == -1} {
 				::windows::gamelist::update_ $w 0
 			} elseif {$filter == $::gamelistFilter($w) || \
-			          $filter == [sc_filter link $::gamelistBase($w) $::gamelistFilter($w)]} {
+			          $filter == [sc_filter compose $::gamelistBase($w) $::gamelistFilter($w) ""]} {
 				::windows::gamelist::update_ $w 1
 			}
 			::windows::gamelist::updateStats_ $w
@@ -132,7 +132,7 @@ proc ::windows::gamelist::PosChanged {{wlist ""}} {
 				if { $::gamelistBase($w) == $base && $::gamelistPosMask($w) != 0 } {
 					$w.games.glist tag configure fsmall -foreground ""
 					$w.buttons.boardFilter configure -image tb_BoardMask
-					set ::gamelistFilter($w) [sc_filter link $::gamelistBase($w) $::gamelistFilter($w) $f]
+					set ::gamelistFilter($w) [sc_filter compose $::gamelistBase($w) $::gamelistFilter($w) $f]
 					::notify::DatabaseModified $base $::gamelistFilter($w)
 				}
 			}
@@ -144,7 +144,7 @@ proc ::windows::gamelist::PosChanged {{wlist ""}} {
 proc ::windows::gamelist::FilterReset {{w} {base}} {
 	set f "dbfilter"
 	if {$w != "" && $base == $::gamelistBase($w)}  { set f $::gamelistFilter($w) }
-	sc_filter set $base $f 1
+	sc_filter reset $base $f full
 	::notify::DatabaseModified $base $f
 }
 
@@ -168,32 +168,39 @@ proc ::windows::gamelist::FilterExport {{w}} {
 	progressWindow "Scid" "Exporting games..." $::tr(Cancel)
 	if {$::gamelistExport == "LaTeX"} {
         if {[file extension $fName] == ""} { append fName ".tex" }
-		sc_filter export $::gamelistBase($w) $::gamelistFilter($w) \
-		                 $::glistSortStr($w.games.glist) $fName $::gamelistExport \
-		                 $::exportStartFile(LaTeX) $::exportEndFile(LaTeX)
+		set err [catch {sc_filter export $::gamelistBase($w) $::gamelistFilter($w) \
+		                    $::glistSortStr($w.games.glist) $fName $::gamelistExport \
+		                    $::exportStartFile(LaTeX) $::exportEndFile(LaTeX) }]
 	} else {
         if {[file extension $fName] == ""} { append fName ".pgn" }
-		sc_filter export $::gamelistBase($w) $::gamelistFilter($w) \
-		                 $::glistSortStr($w.games.glist) $fName $::gamelistExport
+		set err [catch {sc_filter export $::gamelistBase($w) $::gamelistFilter($w) \
+		                    $::glistSortStr($w.games.glist) $fName $::gamelistExport }]
 	}
 	closeProgressWindow
+	if {$err && $::errorCode != $::ERROR::UserCancel} { ERROR::MessageBox }
 }
 
 # Returns text describing state of filter for specified
 # database, e.g. "no games" or "all / 400" or "1,043 / 2,057"
-proc ::windows::gamelist::filterText {{w ""} {base 0}} {
-	if {$base == 0} { set base [sc_base current] }
-	set gameCount [sc_base numGames $base]
-	if {$gameCount == 0} { return $::tr(noGames) }
+proc ::windows::gamelist::filterText {{w ""} {base -1}} {
+	if {$base == -1} { set base [sc_base current] }
 	set f "dbfilter"
 	if {$w != "" && $base == $::gamelistBase($w)}  {
 		set f $::gamelistFilter($w)
 	}
-	set filterCount [sc_filter count $base $f]
-	if {$gameCount == $filterCount} {
-		return "$::tr(all) / [::utils::thousands $gameCount 100000]"
+
+	foreach {filterSz gameSz mainSz} [sc_filter sizes $base $f] {}
+	return [formatFilterText $filterSz $gameSz]
+}
+
+# Returns text describing state of filter for specified
+# database, e.g. "no games" or "all / 400" or "1,043 / 2,057"
+proc ::windows::gamelist::formatFilterText {filterSz gameSz} {
+	if {$gameSz == 0} { return $::tr(noGames) }
+	if {$gameSz == $filterSz} {
+		return "$::tr(all) / [::utils::thousands $gameSz 100000]"
 	}
-	return "[::utils::thousands $filterCount 100000] / [::utils::thousands $gameCount 100000]"
+	return "[::utils::thousands $filterSz 100000] / [::utils::thousands $gameSz 100000]"
 }
 
 proc ::windows::gamelist::GetBase {{w}} {
@@ -241,12 +248,12 @@ proc ::windows::gamelist::SetBase {{w} {base} {filter "dbfilter"}} {
 proc ::windows::gamelist::Awesome {{w} {txt}} {
 	if {[lsearch -exact $::windows::gamelist::wins $w] == -1} { return }
 
-	set filter [sc_filter link $::gamelistBase($w) $::gamelistFilter($w)]
+	set filter [sc_filter compose $::gamelistBase($w) $::gamelistFilter($w) ""]
 	if {$txt == ""} {
 		# Quick way to reset the filter: search an empty string
-		sc_filter set "$::gamelistBase($w)" $filter 1
+		sc_filter reset "$::gamelistBase($w)" $filter full
 	} else {
-		sc_filter set "$::gamelistBase($w)" $filter 0
+		sc_filter reset "$::gamelistBase($w)" $filter empty
 		#Split the string using " + "
 		foreach {dummy sub} [regexp -all -inline {(.+?)(?:\s\+\s|$)} $txt] {
 			set cmd "sc_filter search $::gamelistBase($w) $filter header -filter OR"
@@ -439,7 +446,6 @@ proc ::windows::gamelist::createWin_ { {w} {base} {filter} } {
 	set ::gamelistFilter($w) $filter
 	set ::gamelistPosMask($w) 0
 	set ::gamelistMenu($w) ""
-	keyboardShortcuts $w
 	::windows::gamelist::createMenu_ $w
 	if {[info exists ::recentSort]} {
 		set idx [lsearch -exact $::recentSort "[sc_base filename $base]"]
@@ -457,9 +463,6 @@ proc ::windows::gamelist::createWin_ { {w} {base} {filter} } {
 			::windows::gamelist::filterRelease_ $::gamelistBase(%W) $::gamelistFilter(%W)
 		}
 	}
-	setWinLocation $w
-	setWinSize $w
-	bind $w <Configure> "recordWinSize $w"
 	bind $w <Control-l> "::windows::gamelist::Open \$::gamelistBase($w)"
 	createToplevelFinalize $w
 	lappend ::windows::gamelist::wins $w
@@ -475,12 +478,11 @@ proc ::windows::gamelist::createMenu_ {w} {
 	ttk::button $w.buttons.boardFilter -image tb_BoardMask -command "::windows::gamelist::searchpos_ $w"
 	#TODO:
 	#ttk::button $w.buttons.stats -image b_bargraph
-	#TODO: translate
-	::utils::tooltip::Set $w.buttons.database "Show/Hide databases"
-	::utils::tooltip::Set $w.buttons.filter "Change filter"
-	::utils::tooltip::Set $w.buttons.layout "Load/Save/Change sorting criteria and column layout"
-	::utils::tooltip::Set $w.buttons.stats "Show/Hide statistics"
-	::utils::tooltip::Set $w.buttons.boardFilter "Show only games that matches the current board position"
+	::utils::tooltip::Set $w.buttons.database $::tr(ShowHideDB)
+	::utils::tooltip::Set $w.buttons.filter $::tr(ChangeFilter)
+	::utils::tooltip::Set $w.buttons.layout $::tr(ChangeLayout)
+	::utils::tooltip::Set $w.buttons.stats $::tr(ShowHideStatistic)
+	::utils::tooltip::Set $w.buttons.boardFilter $::tr(BoardFilter)
 	grid $w.buttons.database -row 0
 	grid $w.buttons.filter -row 1
 	grid $w.buttons.layout -row 2
@@ -490,25 +492,25 @@ proc ::windows::gamelist::createMenu_ {w} {
 
 	ttk::frame $w.database -padding {0 5 6 2}
 	::windows::switcher::Create $w.database $w
+	$w.database.border configure -borderwidth 2 -relief groove
 
 	ttk::frame $w.filter -padding {4 5 6 0}
-	ttk::frame $w.filter.b -borderwidth 2 -relief groove
+	ttk::frame $w.filter.b
 	grid $w.filter.b -sticky news
 	grid rowconfigure $w.filter 0 -weight 1
 	grid columnconfigure $w.filter 0 -weight 1
-	set bgcolor [ttk::style lookup Button.label -background]
-	button $w.filter.b.rfilter -image tb_rfilter -background $bgcolor \
-		-command "::windows::gamelist::filter_ $w r" -width 24 -height 24
-	button $w.filter.b.bsearch -image tb_bsearch -background $bgcolor \
-		-command "::windows::gamelist::filter_ $w b" -width 24 -height 24
-	button $w.filter.b.hsearch -image tb_hsearch -background $bgcolor \
-		-command "::windows::gamelist::filter_ $w h" -width 24 -height 24
-	button $w.filter.b.msearch -image tb_msearch -background $bgcolor \
-		-command "::windows::gamelist::filter_ $w m" -width 24 -height 24
-	button $w.filter.b.tmt -image tb_tmt -background $bgcolor \
-		-command ::tourney::toggle -width 24 -height 24
-	button $w.filter.b.crosst -image tb_crosst -background $bgcolor \
-		-command toggleCrosstabWin -width 24 -height 24
+	ttk::button $w.filter.b.rfilter -image tb_rfilter  \
+		-command "::windows::gamelist::filter_ $w r"
+	ttk::button $w.filter.b.bsearch -image tb_bsearch \
+		-command "::windows::gamelist::filter_ $w b"
+	ttk::button $w.filter.b.hsearch -image tb_hsearch \
+		-command "::windows::gamelist::filter_ $w h"
+	ttk::button $w.filter.b.msearch -image tb_msearch \
+		-command "::windows::gamelist::filter_ $w m"
+	ttk::button $w.filter.b.tmt -image tb_tmt \
+		-command ::tourney::toggle
+	ttk::button $w.filter.b.crosst -image tb_crosst \
+		-command ::crosstab::Open
 	#TODO: rewrite the tooltip system (most tooltip are not translated when you change language)
 	::utils::tooltip::Set "$w.filter.b.rfilter" "$::helpMessage($::language,SearchReset)"
 	::utils::tooltip::Set "$w.filter.b.bsearch" "$::helpMessage($::language,SearchCurrent)"
@@ -564,7 +566,7 @@ proc ::windows::gamelist::filter_ {{w} {type}} {
 	if {$type == "r"} {
 		::windows::gamelist::FilterReset $w $::gamelistBase($w)
 	} elseif {$type == "b"} {
-		::search::board $::gamelistBase($w)
+		::search::board $::gamelistBase($w) $::gamelistFilter($w)
 	} elseif {$type == "h"} {
 		::search::header $::gamelistBase($w) $::gamelistFilter($w)
 	} elseif {$type == "m"} {
@@ -573,14 +575,18 @@ proc ::windows::gamelist::filter_ {{w} {type}} {
 }
 
 proc ::windows::gamelist::update_ {{w} {moveUp}} {
-	set fr [::windows::gamelist::filterText $w $::gamelistBase($w)]
-	set fn [file tail [sc_base filename $::gamelistBase($w)]]
-	::setTitle $w "$::gamelistTitle($w) $fn ($fr)"
-	if {[sc_filter isWhole $::gamelistBase($w) $::gamelistFilter($w)]} {
+	set f $::gamelistFilter($w)
+	foreach {filterSz gameSz mainSz} [sc_filter sizes $::gamelistBase($w) $f] {}
+
+	if {$gameSz == $mainSz} {
 		$w.buttons.filter configure -image tb_search_on
 	} else {
 		$w.buttons.filter configure -image tb_search_off
 	}
+
+	set fr [::windows::gamelist::formatFilterText $filterSz $gameSz]
+	set fn [file tail [sc_base filename $::gamelistBase($w)]]
+	::setTitle $w "$::gamelistTitle($w) $fn ($fr)"
 	if {$moveUp} {
 		#Reset double-click behavior
 		set ::glistClickOp($w.games.glist) 0
@@ -596,7 +602,7 @@ proc ::windows::gamelist::searchpos_ {{w}} {
 	} else {
 		set ::gamelistPosMask($w) 0
 		$w.buttons.boardFilter state !pressed
-		set ::gamelistFilter($w) [sc_filter link $::gamelistBase($w) $::gamelistFilter($w)]
+		set ::gamelistFilter($w) [sc_filter compose $::gamelistBase($w) $::gamelistFilter($w) ""]
 		$w.games.glist tag configure fsmall -foreground ""
 		$w.buttons.boardFilter configure -image tb_BoardMask
 		::notify::DatabaseModified $::gamelistBase($w) $::gamelistFilter($w)
@@ -610,7 +616,10 @@ proc ::windows::gamelist::filterRelease_ {{base} {filter}} {
 			incr used
 		}
 	}
-	if {! $used} { catch {sc_filter release $base $filter} }
+	if {! $used} {
+		catch {sc_filter release $base $filter}
+		::notify::DatabaseModified $base $filter
+	}
 }
 
 proc ::windows::gamelist::updateStats_ { {w} } {
@@ -724,8 +733,8 @@ namespace eval ::glist_Ly {
 		if {! [info exists ::glist_Layouts] } { set ::glist_Layouts {} }
 		options.save ::glist_Layouts
 		set ::gamelistNewLayout [::glist_Ly::createName_]
-		set bgcolor [ttk::style lookup Button.label -background]
-		autoscrollframe -bars y $w.layout.b canvas $w.layout.b.c -highlightthickness 0 -background $bgcolor
+		autoscrollframe -bars y $w.layout.b canvas $w.layout.b.c -highlightthickness 0
+		::applyThemeColor_background $w.layout.b.c
 		bind $w.layout.b.c <Configure>  { ::glist_Ly::AdjScrollbar_ %W }
 		::glist_Ly::Update_ $w
 	}
@@ -738,8 +747,8 @@ namespace eval ::glist_Ly {
 		if {[winfo exists $w.layout.b.c.f]} { destroy $w.layout.b.c.f}
 		ttk::frame $w.layout.b.c.f -padding 5
 		$w.layout.b.c create window 0 0 -window $w.layout.b.c.f -anchor nw
-		tk::entry $w.layout.b.c.f.text_new -textvariable ::gamelistNewLayout -font font_Small
-		tk::button $w.layout.b.c.f.new -image tb_new -command "::glist_Ly::New_ $w"
+		ttk::entry $w.layout.b.c.f.text_new -textvariable ::gamelistNewLayout -width 12
+		ttk::button $w.layout.b.c.f.new -image tb_new -command "::glist_Ly::New_ $w"
 		grid $w.layout.b.c.f.text_new $w.layout.b.c.f.new
 		ttk::frame $w.layout.b.c.f.sep -padding { 0 4 0 4 }
 		ttk::separator $w.layout.b.c.f.sep.line
@@ -749,8 +758,8 @@ namespace eval ::glist_Ly {
 		grid $w.layout.b.c.f.sep -columnspan 2 -sticky we
 		for {set i 0} {$i < [llength $::glist_Layouts]} {incr i} {
 			set name [lindex $::glist_Layouts $i]
-			tk::button $w.layout.b.c.f.layout$i -text $name -font font_Small -width 20 -command "::glist_Ly::Change_ $w $i" -bg lightSteelBlue
-			tk::button $w.layout.b.c.f.layoutDel$i -image tb_CC_delete -command "::glist_Ly::Del_ $w $i"
+			ttk::button $w.layout.b.c.f.layout$i -text $name -width 12 -command "::glist_Ly::Change_ $w $i"
+			ttk::button $w.layout.b.c.f.layoutDel$i -image tb_CC_delete -command "::glist_Ly::Del_ $w $i"
 			grid $w.layout.b.c.f.layout$i $w.layout.b.c.f.layoutDel$i -sticky we
 		}
 		after idle "::glist_Ly::AdjScrollbar_ $w.layout.b.c"
@@ -817,28 +826,24 @@ namespace eval ::glist_Ly {
 proc glist.create {{w} {layout}} {
   # Default values
   if {! [info exists ::glist_ColOrder($layout)] } {
-    set ::glist_ColOrder($layout) {{7} {1} {2} {3} {4} {5} {6} {23} {22} {8} {9} {10} {11} {12} {13} {14} {15} {16} {0}}
+    set ::glist_ColOrder($layout) {7 3 4 5 6 1 2 23 8 10 9 16 17 22 21 18 11 12 13 14 15 0}
   }
   if {! [info exists ::glist_ColWidth($layout)] } {
-    set ::glist_ColWidth($layout) {{50} {50} {50} {120} {40} {120} {40} {80} {200} {30} \
-        {200} {30} {20} {20} {20} {20} {35} {50} {30} {100} {40} {40} {50} {140}}
+    set ::glist_ColWidth($layout) {50 50 39 120 40 120 40 70 200 30 200 30 20 20 20 20 35 119 30 78 40 40 50 155}
   }
   if {! [info exists ::glist_ColAnchor($layout)] } {
-    set ::glist_ColAnchor($layout) {{e} {c} {c} {w} {c} {w} {c} {w} {w} {e} \
-        {w} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {c} {w}}
+    set ::glist_ColAnchor($layout) {e c c w c w c w w e w c c c c c c c c c c c c w}
   }
   if {! [info exists ::glist_Sort($layout)] } {
-    set ::glist_Sort($layout) { {22} {-} {7} {-} }
+    set ::glist_Sort($layout) {0 +}
   }
   if {! [info exists ::glist_FindBar($layout)] } {
     set ::glist_FindBar($layout) 0
   }
 
-  ttk::treeview $w.glist -columns $::glist_Headers -show headings -selectmode browse
+  ttk::treeview $w.glist -style Gamelist.Treeview -columns $::glist_Headers -show headings -selectmode browse
   $w.glist tag configure current -background lightSteelBlue
   $w.glist tag configure fsmall -font font_Small
-  set lineH [expr { round(1.4 * [font metrics font_Small -linespace]) }]
-  ttk::style configure Treeview -rowheight $lineH
   $w.glist tag configure deleted -foreground #a5a2ac
   menu $w.glist.header_menu
   menu $w.glist.header_menu.addcol
@@ -847,9 +852,7 @@ proc glist.create {{w} {layout}} {
     set hWin [winfo height %W]
     set hHeading 18
     set space [expr double($hWin - $hHeading)]
-    set hRow [expr {int(1.8*[font metrics font_Small -ascent])} ]
-    ttk::style configure Treeview -rowheight $hRow
-    set ::glistVisibleLn(%W) [expr int(ceil($space / $hRow)) ]
+    set ::glistVisibleLn(%W) [expr int(ceil($space / $::glistRowHeight)) ]
     after 100 "glist.loadvalues_ %W"
   }
   if {$::windowsOS} {
@@ -887,7 +890,7 @@ proc glist.create {{w} {layout}} {
     foreach {idx ply} [split [%W selection] "_"] {}
     if {[info exists idx]} {
       glist.movesel_ %W next +1 end;
-      sc_filter set $::glistBase(%W) $::glistFilter(%W) 0 $idx
+      sc_filter remove $::glistBase(%W) $::glistFilter(%W) $idx
       ::notify::DatabaseModified $::glistBase(%W)
     }
     break
@@ -979,6 +982,8 @@ set glist_Headers {"GlistNumber" "GlistResult" "GlistLength" "GlistWhite" "Glist
                    "GlistFlags" "GlistECO" "GlistEndMaterial" "GlistStart" "GlistEDate"
                    "GlistYear" "GlistAverageElo" "GlistRating" "GlistMoveField" }
 
+set glist_DefaultOrder {+ + - + - + - - + + + - - - - - + + - - - - - +}
+
 set glist_SortShortcuts { "N" "r" "m" "w" "W"
                     "b" "B" "d" "e" "n"
                     "s" "A" "C" "V" "D"
@@ -1154,12 +1159,10 @@ proc glist.doubleclick_ {{w} {x} {y} {layout}} {
 
 proc glist.removeFromFilter_ {{w} {idx} {dir ""}} {
   if {$dir == ""} {
-    sc_filter set $::glistBase($w) $::glistFilter($w) 0 $idx
-    ::notify::DatabaseModified $::glistBase($w)
-    return
+    sc_filter remove $::glistBase($w) $::glistFilter($w) $idx
+  } else {
+    sc_filter remove $::glistBase($w) $::glistFilter($w) $idx $dir $::glistSortStr($w)
   }
-  set fc [sc_filter count $::glistBase($w) $::glistFilter($w)]
-  sc_filter set $::glistBase($w) $::glistFilter($w) 0 $idx $dir$fc $::glistSortStr($w)
   ::notify::DatabaseModified $::glistBase($w) $::glistFilter($w) 
   if {$dir == "+"} { glist.ybar_ $w moveto 1 }
 }
@@ -1200,24 +1203,20 @@ proc glist.popupmenu_ {{w} {x} {y} {abs_x} {abs_y} {layout}} {
               -command "sc_base copygames $::glistBase($w) $idx $i; ::notify::DatabaseModified $i"
       }
       $w.game_menu add cascade -label $::tr(GlistMergeGameInBase) -menu $w.game_menu.merge
-      #TODO: translate label
-      $w.game_menu add cascade -label "Copy Game to" -menu $w.game_menu.copy
+      $w.game_menu add cascade -label $::tr(CopyGameTo) -menu $w.game_menu.copy
 
       #GOTO GAME
       $w.game_menu add separator
-      #TODO: translate label
       $w.game_menu add checkbutton -variable ::glist_FindBar($layout) \
-                   -label "Find Bar" -command "glist.showfindbar_ $w $layout"
+                   -label $::tr(FindBar) -command "glist.showfindbar_ $w $layout"
       if {$::glistBase($w) == [sc_base current] && [sc_game number] != 0} {
-        #TODO: translate label
-        $w.game_menu add command -label "Find current game" -command "glist.findcurrentgame_ $w [sc_game number]"
+        $w.game_menu add command -label $::tr(FindCurrentGame) -command "glist.findcurrentgame_ $w [sc_game number]"
       } else {
-        #TODO: translate label
-        $w.game_menu add command -label "Find current game" -state disabled
+        $w.game_menu add command -label $::tr(FindCurrentGame) -state disabled
       }
       $w.game_menu add separator
       menu $w.game_menu.filter
-      $w.game_menu.filter add command -label "Export" -command "::windows::gamelist::FilterExport [winfo toplevel $w]"
+      $w.game_menu.filter add command -label $::tr(Export) -command "::windows::gamelist::FilterExport [winfo toplevel $w]"
       $w.game_menu.filter add separator
       $w.game_menu.filter add command -label [tr SearchReset] \
         -command "::windows::gamelist::FilterReset [winfo toplevel $w] $::glistBase($w)"
@@ -1237,9 +1236,8 @@ proc glist.popupmenu_ {{w} {x} {y} {abs_x} {abs_y} {layout}} {
         -command "sc_base gameflag $::glistBase($w) $::glistFilter($w) unset del; ::notify::DatabaseModified $::glistBase($w)"
       $w.game_menu add cascade -label $::tr(Filter) -menu $w.game_menu.filter
       $w.game_menu add separator
-      #TODO: translate labels
-      set dellabel "Delete game"
-      if {[sc_base gameflag $::glistBase($w) $idx get del]} { set dellabel "Undelete game" }
+      set dellabel $::tr(DeleteGame)
+      if {[sc_base gameflag $::glistBase($w) $idx get del]} { set dellabel $::tr(UndeleteGame) }
       $w.game_menu add command -label $dellabel -command "glist.delflag_ $w $idx; $w selection set {};"
       tk_popup $w.game_menu $abs_x $abs_y
     }
@@ -1280,14 +1278,12 @@ proc glist.popupmenu_ {{w} {x} {y} {abs_x} {abs_y} {layout}} {
 
     #RESET SORT
     $w.header_menu add separator
-    #TODO: translate label
-    $w.header_menu add command -label "Reset sort" -command "glist.sort_ $w 0 $layout 1"
+    $w.header_menu add command -label $::tr(ResetSort) -command "glist.sort_ $w 0 $layout 1"
 
     #BARS
     $w.header_menu add separator
-    #TODO: translate label
     $w.header_menu add checkbutton -variable ::glist_FindBar($layout) \
-                   -label "Find Bar" -command "glist.showfindbar_ $w $layout"
+                   -label $::tr(FindBar) -command "glist.showfindbar_ $w $layout"
 
     tk_popup $w.header_menu $abs_x $abs_y
   }
@@ -1325,7 +1321,8 @@ proc glist.sort_ {{w} {col_idx} {layout} {clear 0}} {
 
   set exists [lsearch -exact $::glist_Sort($layout) $col_idx ]
   if {$exists == -1} {
-    lappend ::glist_Sort($layout) $col_idx -
+    set order [lindex $::glist_DefaultOrder $col_idx]
+    lappend ::glist_Sort($layout) $col_idx $order
   } else {
     incr exists
     if {[lindex $::glist_Sort($layout) $exists ] == "+"} {
