@@ -497,6 +497,15 @@ set numBaseTypeIcons [llength $::windows::switcher::base_types]
 
 set temp_dbtype 0
 
+proc getBaseType {baseId} {
+  foreach {tagname tagvalue} [sc_base extra $baseId] {
+    if {$tagname eq "type"} {
+      return $tagvalue
+    }
+  }
+  return 0
+}
+
 proc selectBaseType {type} {
   global temp_dbtype
   set w .btypeWin
@@ -520,19 +529,19 @@ proc clickBaseType {x y} {
 proc changeBaseType {baseNum} {
   global temp_dbtype ::windows::switcher::base_types numBaseTypeIcons
   if {$baseNum > [sc_info limit bases]} { return }
-  set temp_dbtype [sc_base extra $baseNum type]
+  set temp_dbtype [getBaseType $baseNum]
   if {$temp_dbtype >= $numBaseTypeIcons} { set temp_dbtype 0 }
-  toplevel .btypeWin
   set w .btypeWin
-  wm title $w "Scid: Choose database icon"
+  win::createDialog $w
+  wm title $w "Scid: $::tr(ChangeIcon)"
 
   text $w.t -yscrollcommand "$w.yscroll set" -font font_Regular \
     -height 25 -width 40 -background white -wrap none \
     -cursor top_left_arrow
   $w.t tag configure selected -background lightSteelBlue
 
-  scrollbar $w.yscroll -command "$w.t yview" -takefocus 0
-  pack [frame $w.b] -side bottom -pady 5
+  ttk::scrollbar $w.yscroll -command "$w.t yview" -takefocus 0
+  pack [ttk::frame $w.b] -side bottom -anchor e
   pack $w.yscroll -side right -fill y
   pack $w.t -side left -fill both -expand yes
 
@@ -541,7 +550,7 @@ proc changeBaseType {baseNum} {
      focus .; destroy $w"
 
   dialogbutton $w.b.cancel -text $::tr(Cancel) -command "focus .; destroy $w"
-  pack $w.b.set $w.b.cancel -side left -padx 5
+  packdlgbuttons $w.b.cancel $w.b.set
 
   set numtypes [llength $base_types]
   for {set i  0} {$i < $numtypes} {incr i} {
@@ -614,7 +623,7 @@ proc ::windows::switcher::releaseMouseEvent {fromBase x y {w .baseWin}} {
 
 proc ::windows::switcher::popupmenu { {switcherWin} {w} {abs_x} {abs_y} {baseIdx} } {
   $w.menu delete 0 end
-  $w.menu add command -label "New Game List Window" -command "::windows::gamelist::Open $baseIdx"
+  $w.menu add command -label "[tr NewGameListWindow]" -command "::windows::gamelist::Open $baseIdx"
   $w.menu add separator
   $w.menu add command -label [tr FileOpen] -command ::file::Open
   if {![sc_base isReadOnly $baseIdx]} {
@@ -630,11 +639,11 @@ proc ::windows::switcher::popupmenu { {switcherWin} {w} {abs_x} {abs_y} {baseIdx
     $w.menu add command -label $::tr(CompactDatabase) -command "compactDB $baseIdx"
     if { [::file::autoLoadBases.find $baseIdx] == "-1" } {
       set ::sw_DummyCheckbutton 0
-      $w.menu add checkbutton -label "Load at startup" -variable ::sw_DummyCheckbutton \
+      $w.menu add checkbutton -label "[tr LoadatStartup]" -variable ::sw_DummyCheckbutton \
         -command "::file::autoLoadBases.add $baseIdx"
     } else {
       set ::sw_DummyCheckbutton 1
-      $w.menu add checkbutton -label "Load at startup" -variable ::sw_DummyCheckbutton \
+      $w.menu add checkbutton -label "[tr LoadatStartup]" -variable ::sw_DummyCheckbutton \
         -command "::file::autoLoadBases.remove $baseIdx"
     }
   } else {
@@ -660,17 +669,13 @@ proc ::windows::switcher::Open {{w .baseWin}} {
     return
   }
   
-  setWinLocation $w
   ::setTitle $w "Scid: [tr WindowsSwitcher]"
   ::windows::switcher::Create $w
   bind $w <Escape> "focus .; destroy $w"
   bind $w <Destroy> "+ if {\[string equal $w %W\]} {set ::baseWin 0}"
   bind $w <F1> { helpWindow Switcher }
-  keyboardShortcuts $w
   label $w.status -width 1 -anchor w -relief sunken -borderwidth 1
   grid $w.status -columnspan 2 -sticky we
-  bind $w <Configure> "+recordWinSize $w"
-  setWinSize $w
   ::createToplevelFinalize $w
   after idle "::windows::switcher::Update_ $w"
 }
@@ -682,14 +687,14 @@ proc ::windows::switcher::Create {{w} {gamelist ""}} {
     set ::sw_LinkedGList_($w) $gamelist
   }
 
-  ttk::frame $w.border -borderwidth 2 -relief groove
+  ttk::frame $w.border
   grid $w.border -sticky news
   grid rowconfigure $w 0 -weight 1
   grid columnconfigure $w 0 -weight 1
   autoscrollframe -bars y $w.border canvas $w.c -highlightthickness 0
 
   for {set i 1} {$i <= $::sw_nBases_} {incr i} {
-    set f [frame $w.c.f$i -background white -borderwidth 1 -relief raised]
+    set f [ttk::frame $w.c.f$i -borderwidth 1 -relief raised]
     $w.c create window 0 0 -window $w.c.f$i -anchor nw -tag tag$i
 
     set f $w.c.f$i
@@ -731,9 +736,9 @@ proc ::windows::switcher::calcSpace {{w} {selected}} {
       set color white
       if {$i == $selected} { set color lightSteelBlue }
 
-      $w.c.f$i configure -background $color
+#      $w.c.f$i configure -background $color
       if {$icons} {
-        set dbtype [sc_base extra $i type]
+        set dbtype [getBaseType $i]
         if {$dbtype >= $numBaseTypeIcons} { set dbtype 0 }
         $w.c.f$i.img configure -image dbt$dbtype -background $color
 		grid $w.c.f$i.img -row 0 -column 0 -rowspan 2
@@ -785,7 +790,8 @@ proc ::windows::switcher::Draw {{w} {numColumns} {iconWidth} {iconHeight} } {
   set right [expr {$numColumns * $iconWidth}]
   set bottom [expr {$numRows * $iconHeight}]
   set bgcolor [ttk::style lookup Button.label -background]
-  $w.c configure -scrollregion [list 0 0 $right $bottom] -borderwidth 4 -relief flat -background $bgcolor
+  $w.c configure -scrollregion [list 0 0 $right $bottom] -borderwidth 4 -relief flat
+  ::applyThemeColor_background $w.c
 }
 
 proc ::windows::switcher::Refresh {} {
